@@ -1,40 +1,38 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Server config checks management
- *
- * @package PhpMyAdmin
  */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Config;
 
-use PhpMyAdmin\Config\ConfigFile;
-use PhpMyAdmin\Config\Descriptions;
 use PhpMyAdmin\Core;
 use PhpMyAdmin\Sanitize;
 use PhpMyAdmin\Setup\Index as SetupIndex;
 use PhpMyAdmin\Url;
 use PhpMyAdmin\Util;
+use function count;
+use function function_exists;
+use function htmlspecialchars;
+use function implode;
+use function ini_get;
+use function preg_match;
+use function sprintf;
+use function strlen;
 
 /**
  * Performs various compatibility, security and consistency checks on current config
  *
  * Outputs results to message list, must be called between SetupIndex::messagesBegin()
  * and SetupIndex::messagesEnd()
- *
- * @package PhpMyAdmin
  */
 class ServerConfigChecks
 {
-    /**
-     * @var ConfigFile configurations being checked
-     */
+    /** @var ConfigFile configurations being checked */
     protected $cfg;
 
     /**
-     * Constructor.
-     *
      * @param ConfigFile $cfg Configuration
      */
     public function __construct(ConfigFile $cfg)
@@ -53,7 +51,7 @@ class ServerConfigChecks
         $blowfishSecretSet = false;
         $cookieAuthUsed = false;
 
-        list($cookieAuthUsed, $blowfishSecret, $blowfishSecretSet)
+        [$cookieAuthUsed, $blowfishSecret, $blowfishSecretSet]
             = $this->performConfigChecksServers(
                 $cookieAuthUsed,
                 $blowfishSecret,
@@ -66,10 +64,8 @@ class ServerConfigChecks
             $blowfishSecret
         );
 
-        //
         // $cfg['AllowArbitraryServer']
         // should be disabled
-        //
         if ($this->cfg->getValue('AllowArbitraryServer')) {
             $sAllowArbitraryServerWarn = sprintf(
                 __(
@@ -103,10 +99,8 @@ class ServerConfigChecks
             . 'your server.'
         );
 
-        //
         // $cfg['SaveDir']
         // should not be world-accessible
-        //
         if ($this->cfg->getValue('SaveDir') != '') {
             SetupIndex::messagesSet(
                 'notice',
@@ -116,10 +110,8 @@ class ServerConfigChecks
             );
         }
 
-        //
         // $cfg['TempDir']
         // should not be world-accessible
-        //
         if ($this->cfg->getValue('TempDir') != '') {
             SetupIndex::messagesSet(
                 'notice',
@@ -135,9 +127,9 @@ class ServerConfigChecks
     /**
      * Check config of servers
      *
-     * @param boolean $cookieAuthUsed    Cookie auth is used
-     * @param string  $blowfishSecret    Blowfish secret
-     * @param boolean $blowfishSecretSet Blowfish secret set
+     * @param bool   $cookieAuthUsed    Cookie auth is used
+     * @param string $blowfishSecret    Blowfish secret
+     * @param bool   $blowfishSecretSet Blowfish secret set
      *
      * @return array
      */
@@ -149,7 +141,7 @@ class ServerConfigChecks
         $serverCnt = $this->cfg->getServerCount();
         for ($i = 1; $i <= $serverCnt; $i++) {
             $cookieAuthServer
-                = ($this->cfg->getValue("Servers/$i/auth_type") == 'cookie');
+                = ($this->cfg->getValue('Servers/' . $i . '/auth_type') === 'cookie');
             $cookieAuthUsed |= $cookieAuthServer;
             $serverName = $this->performConfigChecksServersGetServerName(
                 $this->cfg->getServerName($i),
@@ -157,22 +149,20 @@ class ServerConfigChecks
             );
             $serverName = htmlspecialchars($serverName);
 
-            list($blowfishSecret, $blowfishSecretSet)
+            [$blowfishSecret, $blowfishSecretSet]
                 = $this->performConfigChecksServersSetBlowfishSecret(
                     $blowfishSecret,
                     $cookieAuthServer,
                     $blowfishSecretSet
                 );
 
-            //
             // $cfg['Servers'][$i]['ssl']
             // should be enabled if possible
-            //
-            if (! $this->cfg->getValue("Servers/$i/ssl")) {
-                $title = Descriptions::get('Servers/1/ssl') . " ($serverName)";
+            if (! $this->cfg->getValue('Servers/' . $i . '/ssl')) {
+                $title = Descriptions::get('Servers/1/ssl') . ' (' . $serverName . ')';
                 SetupIndex::messagesSet(
                     'notice',
-                    "Servers/$i/ssl",
+                    'Servers/' . $i . '/ssl',
                     $title,
                     __(
                         'You should use SSL connections if your database server '
@@ -193,19 +183,17 @@ class ServerConfigChecks
                 '[/a]'
             ));
 
-            //
             // $cfg['Servers'][$i]['auth_type']
             // warn about full user credentials if 'auth_type' is 'config'
-            //
-            if ($this->cfg->getValue("Servers/$i/auth_type") == 'config'
-                && $this->cfg->getValue("Servers/$i/user") != ''
-                && $this->cfg->getValue("Servers/$i/password") != ''
+            if ($this->cfg->getValue('Servers/' . $i . '/auth_type') === 'config'
+                && $this->cfg->getValue('Servers/' . $i . '/user') != ''
+                && $this->cfg->getValue('Servers/' . $i . '/password') != ''
             ) {
                 $title = Descriptions::get('Servers/1/auth_type')
-                    . " ($serverName)";
+                    . ' (' . $serverName . ')';
                 SetupIndex::messagesSet(
                     'notice',
-                    "Servers/$i/auth_type",
+                    'Servers/' . $i . '/auth_type',
                     $title,
                     Sanitize::sanitizeMessage(sprintf(
                         __(
@@ -222,25 +210,26 @@ class ServerConfigChecks
                 );
             }
 
-            //
             // $cfg['Servers'][$i]['AllowRoot']
             // $cfg['Servers'][$i]['AllowNoPassword']
             // serious security flaw
-            //
-            if ($this->cfg->getValue("Servers/$i/AllowRoot")
-                && $this->cfg->getValue("Servers/$i/AllowNoPassword")
+            if (! $this->cfg->getValue('Servers/' . $i . '/AllowRoot')
+                || ! $this->cfg->getValue('Servers/' . $i . '/AllowNoPassword')
             ) {
-                $title = Descriptions::get('Servers/1/AllowNoPassword')
-                    . " ($serverName)";
-                SetupIndex::messagesSet(
-                    'notice',
-                    "Servers/$i/AllowNoPassword",
-                    $title,
-                    __('You allow for connecting to the server without a password.')
-                    . ' ' . $sSecurityInfoMsg
-                );
+                continue;
             }
+
+            $title = Descriptions::get('Servers/1/AllowNoPassword')
+                . ' (' . $serverName . ')';
+            SetupIndex::messagesSet(
+                'notice',
+                'Servers/' . $i . '/AllowNoPassword',
+                $title,
+                __('You allow for connecting to the server without a password.')
+                . ' ' . $sSecurityInfoMsg
+            );
         }
+
         return [
             $cookieAuthUsed,
             $blowfishSecret,
@@ -251,9 +240,9 @@ class ServerConfigChecks
     /**
      * Set blowfish secret
      *
-     * @param string  $blowfishSecret    Blowfish secret
-     * @param boolean $cookieAuthServer  Cookie auth is used
-     * @param boolean $blowfishSecretSet Blowfish secret set
+     * @param string|null $blowfishSecret    Blowfish secret
+     * @param bool        $cookieAuthServer  Cookie auth is used
+     * @param bool        $blowfishSecretSet Blowfish secret set
      *
      * @return array
      */
@@ -261,11 +250,12 @@ class ServerConfigChecks
         $blowfishSecret,
         $cookieAuthServer,
         $blowfishSecretSet
-    ) {
+    ): array {
         if ($cookieAuthServer && $blowfishSecret === null) {
             $blowfishSecretSet = true;
             $this->cfg->set('blowfish_secret', Util::generateRandom(32));
         }
+
         return [
             $blowfishSecret,
             $blowfishSecretSet,
@@ -284,10 +274,10 @@ class ServerConfigChecks
         $serverName,
         $serverId
     ) {
-        if ($serverName == 'localhost') {
-            $serverName .= " [$serverId]";
-            return $serverName;
+        if ($serverName === 'localhost') {
+            return $serverName . ' [' . $serverId . ']';
         }
+
         return $serverName;
     }
 
@@ -310,10 +300,8 @@ class ServerConfigChecks
      */
     protected function performConfigChecksServersZipdump()
     {
-        //
         // $cfg['ZipDump']
         // requires zip_open in import
-        //
         if ($this->cfg->getValue('ZipDump') && ! $this->functionExists('zip_open')) {
             SetupIndex::messagesSet(
                 'error',
@@ -331,34 +319,34 @@ class ServerConfigChecks
             );
         }
 
-        //
         // $cfg['ZipDump']
         // requires gzcompress in export
-        //
-        if ($this->cfg->getValue('ZipDump') && ! $this->functionExists('gzcompress')) {
-            SetupIndex::messagesSet(
-                'error',
-                'ZipDump_export',
-                Descriptions::get('ZipDump'),
-                Sanitize::sanitizeMessage(sprintf(
-                    __(
-                        '%sZip compression%s requires functions (%s) which are unavailable on '
-                        . 'this system.'
-                    ),
-                    '[a@' . Url::getCommon(['page' => 'form', 'formset' => 'Features']) . '#tab_Import_export]',
-                    '[/a]',
-                    'gzcompress'
-                ))
-            );
+        if (! $this->cfg->getValue('ZipDump') || $this->functionExists('gzcompress')) {
+            return;
         }
+
+        SetupIndex::messagesSet(
+            'error',
+            'ZipDump_export',
+            Descriptions::get('ZipDump'),
+            Sanitize::sanitizeMessage(sprintf(
+                __(
+                    '%sZip compression%s requires functions (%s) which are unavailable on '
+                    . 'this system.'
+                ),
+                '[a@' . Url::getCommon(['page' => 'form', 'formset' => 'Features']) . '#tab_Import_export]',
+                '[/a]',
+                'gzcompress'
+            ))
+        );
     }
 
     /**
      * Check config of servers
      *
-     * @param boolean $cookieAuthUsed    Cookie auth is used
-     * @param boolean $blowfishSecretSet Blowfish secret set
-     * @param string  $blowfishSecret    Blowfish secret
+     * @param bool   $cookieAuthUsed    Cookie auth is used
+     * @param bool   $blowfishSecretSet Blowfish secret set
+     * @param string $blowfishSecret    Blowfish secret
      *
      * @return void
      */
@@ -367,53 +355,53 @@ class ServerConfigChecks
         $blowfishSecretSet,
         $blowfishSecret
     ) {
-        //
         // $cfg['blowfish_secret']
         // it's required for 'cookie' authentication
-        //
-        if ($cookieAuthUsed) {
-            if ($blowfishSecretSet) {
-                // 'cookie' auth used, blowfish_secret was generated
+        if (! $cookieAuthUsed) {
+            return;
+        }
+
+        if ($blowfishSecretSet) {
+            // 'cookie' auth used, blowfish_secret was generated
+            SetupIndex::messagesSet(
+                'notice',
+                'blowfish_secret_created',
+                Descriptions::get('blowfish_secret'),
+                Sanitize::sanitizeMessage(__(
+                    'You didn\'t have blowfish secret set and have enabled '
+                    . '[kbd]cookie[/kbd] authentication, so a key was automatically '
+                    . 'generated for you. It is used to encrypt cookies; you don\'t need to '
+                    . 'remember it.'
+                ))
+            );
+        } else {
+            $blowfishWarnings = [];
+            // check length
+            if (strlen($blowfishSecret) < 32) {
+                // too short key
+                $blowfishWarnings[] = __(
+                    'Key is too short, it should have at least 32 characters.'
+                );
+            }
+            // check used characters
+            $hasDigits = (bool) preg_match('/\d/', $blowfishSecret);
+            $hasChars = (bool) preg_match('/\S/', $blowfishSecret);
+            $hasNonword = (bool) preg_match('/\W/', $blowfishSecret);
+            if (! $hasDigits || ! $hasChars || ! $hasNonword) {
+                $blowfishWarnings[] = Sanitize::sanitizeMessage(
+                    __(
+                        'Key should contain letters, numbers [em]and[/em] '
+                        . 'special characters.'
+                    )
+                );
+            }
+            if (! empty($blowfishWarnings)) {
                 SetupIndex::messagesSet(
-                    'notice',
-                    'blowfish_secret_created',
+                    'error',
+                    'blowfish_warnings' . count($blowfishWarnings),
                     Descriptions::get('blowfish_secret'),
-                    Sanitize::sanitizeMessage(__(
-                        'You didn\'t have blowfish secret set and have enabled '
-                        . '[kbd]cookie[/kbd] authentication, so a key was automatically '
-                        . 'generated for you. It is used to encrypt cookies; you don\'t need to '
-                        . 'remember it.'
-                    ))
+                    implode('<br>', $blowfishWarnings)
                 );
-            } else {
-                $blowfishWarnings = [];
-                // check length
-                if (strlen($blowfishSecret) < 32) {
-                    // too short key
-                    $blowfishWarnings[] = __(
-                        'Key is too short, it should have at least 32 characters.'
-                    );
-                }
-                // check used characters
-                $hasDigits = (bool) preg_match('/\d/', $blowfishSecret);
-                $hasChars = (bool) preg_match('/\S/', $blowfishSecret);
-                $hasNonword = (bool) preg_match('/\W/', $blowfishSecret);
-                if (! $hasDigits || ! $hasChars || ! $hasNonword) {
-                    $blowfishWarnings[] = Sanitize::sanitizeMessage(
-                        __(
-                            'Key should contain letters, numbers [em]and[/em] '
-                            . 'special characters.'
-                        )
-                    );
-                }
-                if (! empty($blowfishWarnings)) {
-                    SetupIndex::messagesSet(
-                        'error',
-                        'blowfish_warnings' . count($blowfishWarnings),
-                        Descriptions::get('blowfish_secret'),
-                        implode('<br>', $blowfishWarnings)
-                    );
-                }
             }
         }
     }
@@ -425,7 +413,6 @@ class ServerConfigChecks
      */
     protected function performConfigChecksLoginCookie()
     {
-        //
         // $cfg['LoginCookieValidity']
         // value greater than session.gc_maxlifetime will cause
         // random session invalidation after that time
@@ -451,10 +438,8 @@ class ServerConfigChecks
             );
         }
 
-        //
         // $cfg['LoginCookieValidity']
         // should be at most 1800 (30 min)
-        //
         if ($loginCookieValidity > 1800) {
             SetupIndex::messagesSet(
                 'notice',
@@ -472,31 +457,31 @@ class ServerConfigChecks
             );
         }
 
-        //
         // $cfg['LoginCookieValidity']
         // $cfg['LoginCookieStore']
         // LoginCookieValidity must be less or equal to LoginCookieStore
-        //
-        if (($this->cfg->getValue('LoginCookieStore') != 0)
-            && ($loginCookieValidity > $this->cfg->getValue('LoginCookieStore'))
+        if (($this->cfg->getValue('LoginCookieStore') == 0)
+            || ($loginCookieValidity <= $this->cfg->getValue('LoginCookieStore'))
         ) {
-            SetupIndex::messagesSet(
-                'error',
-                'LoginCookieValidity',
-                Descriptions::get('LoginCookieValidity'),
-                Sanitize::sanitizeMessage(sprintf(
-                    __(
-                        'If using [kbd]cookie[/kbd] authentication and %sLogin cookie store%s '
-                        . 'is not 0, %sLogin cookie validity%s must be set to a value less or '
-                        . 'equal to it.'
-                    ),
-                    '[a@' . Url::getCommon(['page' => 'form', 'formset' => 'Features']) . '#tab_Security]',
-                    '[/a]',
-                    '[a@' . Url::getCommon(['page' => 'form', 'formset' => 'Features']) . '#tab_Security]',
-                    '[/a]'
-                ))
-            );
+            return;
         }
+
+        SetupIndex::messagesSet(
+            'error',
+            'LoginCookieValidity',
+            Descriptions::get('LoginCookieValidity'),
+            Sanitize::sanitizeMessage(sprintf(
+                __(
+                    'If using [kbd]cookie[/kbd] authentication and %sLogin cookie store%s '
+                    . 'is not 0, %sLogin cookie validity%s must be set to a value less or '
+                    . 'equal to it.'
+                ),
+                '[a@' . Url::getCommon(['page' => 'form', 'formset' => 'Features']) . '#tab_Security]',
+                '[/a]',
+                '[a@' . Url::getCommon(['page' => 'form', 'formset' => 'Features']) . '#tab_Security]',
+                '[/a]'
+            ))
+        );
     }
 
     /**
@@ -506,36 +491,36 @@ class ServerConfigChecks
      */
     protected function performConfigChecksServerBZipdump()
     {
-        //
         // $cfg['BZipDump']
         // requires bzip2 functions
-        //
-        if ($this->cfg->getValue('BZipDump')
-            && (! $this->functionExists('bzopen') || ! $this->functionExists('bzcompress'))
+        if (! $this->cfg->getValue('BZipDump')
+            || ($this->functionExists('bzopen') && $this->functionExists('bzcompress'))
         ) {
-            $functions = $this->functionExists('bzopen')
-                ? '' :
-                'bzopen';
-            $functions .= $this->functionExists('bzcompress')
-                ? ''
-                : ($functions ? ', ' : '') . 'bzcompress';
-            SetupIndex::messagesSet(
-                'error',
-                'BZipDump',
-                Descriptions::get('BZipDump'),
-                Sanitize::sanitizeMessage(
-                    sprintf(
-                        __(
-                            '%1$sBzip2 compression and decompression%2$s requires functions (%3$s) which '
-                             . 'are unavailable on this system.'
-                        ),
-                        '[a@' . Url::getCommon(['page' => 'form', 'formset' => 'Features']) . '#tab_Import_export]',
-                        '[/a]',
-                        $functions
-                    )
-                )
-            );
+            return;
         }
+
+        $functions = $this->functionExists('bzopen')
+            ? '' :
+            'bzopen';
+        $functions .= $this->functionExists('bzcompress')
+            ? ''
+            : ($functions ? ', ' : '') . 'bzcompress';
+        SetupIndex::messagesSet(
+            'error',
+            'BZipDump',
+            Descriptions::get('BZipDump'),
+            Sanitize::sanitizeMessage(
+                sprintf(
+                    __(
+                        '%1$sBzip2 compression and decompression%2$s requires functions (%3$s) which '
+                         . 'are unavailable on this system.'
+                    ),
+                    '[a@' . Url::getCommon(['page' => 'form', 'formset' => 'Features']) . '#tab_Import_export]',
+                    '[/a]',
+                    $functions
+                )
+            )
+        );
     }
 
     /**
@@ -545,28 +530,28 @@ class ServerConfigChecks
      */
     protected function performConfigChecksServerGZipdump()
     {
-        //
         // $cfg['GZipDump']
         // requires zlib functions
-        //
-        if ($this->cfg->getValue('GZipDump')
-            && (! $this->functionExists('gzopen') || ! $this->functionExists('gzencode'))
+        if (! $this->cfg->getValue('GZipDump')
+            || ($this->functionExists('gzopen') && $this->functionExists('gzencode'))
         ) {
-            SetupIndex::messagesSet(
-                'error',
-                'GZipDump',
-                Descriptions::get('GZipDump'),
-                Sanitize::sanitizeMessage(sprintf(
-                    __(
-                        '%1$sGZip compression and decompression%2$s requires functions (%3$s) which '
-                        . 'are unavailable on this system.'
-                    ),
-                    '[a@' . Url::getCommon(['page' => 'form', 'formset' => 'Features']) . '#tab_Import_export]',
-                    '[/a]',
-                    'gzencode'
-                ))
-            );
+            return;
         }
+
+        SetupIndex::messagesSet(
+            'error',
+            'GZipDump',
+            Descriptions::get('GZipDump'),
+            Sanitize::sanitizeMessage(sprintf(
+                __(
+                    '%1$sGZip compression and decompression%2$s requires functions (%3$s) which '
+                    . 'are unavailable on this system.'
+                ),
+                '[a@' . Url::getCommon(['page' => 'form', 'formset' => 'Features']) . '#tab_Import_export]',
+                '[/a]',
+                'gzencode'
+            ))
+        );
     }
 
     /**
@@ -574,7 +559,7 @@ class ServerConfigChecks
      *
      * @param string $name Function name
      *
-     * @return boolean
+     * @return bool
      */
     protected function functionExists($name)
     {
