@@ -1,10 +1,5 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * Holds the PhpMyAdmin\Controllers\HomeController
- *
- * @package PhpMyAdmin\Controllers
- */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Controllers;
@@ -15,7 +10,8 @@ use PhpMyAdmin\Charsets\Collation;
 use PhpMyAdmin\CheckUserPrivileges;
 use PhpMyAdmin\Config;
 use PhpMyAdmin\DatabaseInterface;
-use PhpMyAdmin\Display\GitRevision;
+use PhpMyAdmin\Git;
+use PhpMyAdmin\Html\Generator;
 use PhpMyAdmin\LanguageManager;
 use PhpMyAdmin\Message;
 use PhpMyAdmin\RecentFavoriteTable;
@@ -27,51 +23,67 @@ use PhpMyAdmin\ThemeManager;
 use PhpMyAdmin\Url;
 use PhpMyAdmin\UserPreferences;
 use PhpMyAdmin\Util;
+use const E_USER_NOTICE;
+use const E_USER_WARNING;
+use const PHP_VERSION;
+use function count;
+use function extension_loaded;
+use function file_exists;
+use function ini_get;
+use function preg_match;
+use function sprintf;
+use function strlen;
+use function strtotime;
+use function trigger_error;
 
-/**
- * Class HomeController
- * @package PhpMyAdmin\Controllers
- */
 class HomeController extends AbstractController
 {
-    /**
-     * @var Config
-     */
+    /** @var Config */
     private $config;
 
-    /**
-     * @var ThemeManager
-     */
+    /** @var ThemeManager */
     private $themeManager;
 
+    /** @var DatabaseInterface */
+    private $dbi;
+
     /**
-     * HomeController constructor.
-     *
-     * @param Response          $response     Response instance
-     * @param DatabaseInterface $dbi          DatabaseInterface instance
-     * @param Template          $template     Template object
-     * @param Config            $config       Config instance
-     * @param ThemeManager      $themeManager ThemeManager instance
+     * @param Response          $response
+     * @param Config            $config
+     * @param DatabaseInterface $dbi
      */
-    public function __construct($response, $dbi, Template $template, $config, ThemeManager $themeManager)
+    public function __construct($response, Template $template, $config, ThemeManager $themeManager, $dbi)
     {
-        parent::__construct($response, $dbi, $template);
+        parent::__construct($response, $template);
         $this->config = $config;
         $this->themeManager = $themeManager;
+        $this->dbi = $dbi;
     }
 
-
-    /**
-     * @return string HTML
-     */
-    public function index(): string
+    public function index(): void
     {
-        global $cfg, $server, $collation_connection, $message;
+        global $cfg, $server, $collation_connection, $message, $show_query, $db, $table, $err_url;
+
+        if ($this->response->isAjax() && ! empty($_REQUEST['access_time'])) {
+            return;
+        }
+
+        // This is for $cfg['ShowDatabasesNavigationAsTree'] = false;
+        // See: https://github.com/phpmyadmin/phpmyadmin/issues/16520
+        // The DB is defined here and sent to the JS front-end to refresh the DB tree
+        $db = $_POST['db'] ?? '';
+        $table = '';
+        $show_query = '1';
+        $err_url = Url::getFromRoute('/');
+
+        if ($server > 0 && $this->dbi->isSuperUser()) {
+            $this->dbi->selectDb('mysql');
+        }
 
         $languageManager = LanguageManager::getInstance();
 
         if (! empty($message)) {
-            $displayMessage = Util::getMessage($message);
+            $displayMessage = Generator::getMessage($message);
             unset($message);
         }
         if (isset($_SESSION['partial_logout'])) {
@@ -99,23 +111,6 @@ class HomeController extends AbstractController
                 $checkUserPrivileges = new CheckUserPrivileges($this->dbi);
                 $checkUserPrivileges->getPrivileges();
 
-                if (($cfg['Server']['auth_type'] != 'config') && $cfg['ShowChgPassword']) {
-                    $changePassword = $this->template->render('list/item', [
-                        'content' => Util::getImage('s_passwd') . ' ' . __(
-                            'Change password'
-                        ),
-                        'id' => 'li_change_password',
-                        'class' => 'no_bullets',
-                        'url' => [
-                            'href' => 'user_password.php' . Url::getCommon(),
-                            'target' => null,
-                            'id' => 'change_password_anchor',
-                            'class' => 'ajax',
-                        ],
-                        'mysql_help_page' => null,
-                    ]);
-                }
-
                 $charsets = Charsets::getCharsets($this->dbi, $cfg['Server']['DisableIS']);
                 $collations = Charsets::getCollations($this->dbi, $cfg['Server']['DisableIS']);
                 $charsetsList = [];
@@ -136,21 +131,6 @@ class HomeController extends AbstractController
                         'collations' => $collationsList,
                     ];
                 }
-
-                $userPreferences = $this->template->render('list/item', [
-                    'content' => Util::getImage('b_tblops') . ' ' . __(
-                        'More settings'
-                    ),
-                    'id' => 'li_user_preferences',
-                    'class' => 'no_bullets',
-                    'url' => [
-                        'href' => 'prefs_manage.php' . Url::getCommon(),
-                        'target' => null,
-                        'id' => null,
-                        'class' => null,
-                    ],
-                    'mysql_help_page' => null,
-                ]);
             }
         }
 
@@ -184,7 +164,7 @@ class HomeController extends AbstractController
             $databaseServer = [
                 'host' => $hostInfo,
                 'type' => Util::getServerType(),
-                'connection' => Util::getServerSSL(),
+                'connection' => Generator::getServerSSL(),
                 'version' => $this->dbi->getVersionString() . ' - ' . $this->dbi->getVersionComment(),
                 'protocol' => $this->dbi->getProtoInfo(),
                 'user' => $this->dbi->fetchValue('SELECT USER();'),
@@ -207,20 +187,6 @@ class HomeController extends AbstractController
                 $webServer['php_version'] = PHP_VERSION;
             }
         }
-        if ($cfg['ShowPhpInfo']) {
-            $phpInfo = $this->template->render('list/item', [
-                'content' => __('Show PHP information'),
-                'id' => 'li_phpinfo',
-                'class' => null,
-                'url' => [
-                    'href' => 'phpinfo.php' . Url::getCommon(),
-                    'target' => '_blank',
-                    'id' => null,
-                    'class' => null,
-                ],
-                'mysql_help_page' => null,
-            ]);
-        }
 
         $relation = new Relation($this->dbi);
         if ($server > 0) {
@@ -241,7 +207,10 @@ class HomeController extends AbstractController
                         );
                 }
                 $messageInstance = Message::notice($messageText);
-                $messageInstance->addParamHtml('<a href="./chk_rel.php" data-post="' . Url::getCommon() . '">');
+                $messageInstance->addParamHtml(
+                    '<a href="' . Url::getFromRoute('/check-relations')
+                    . '" data-post="' . Url::getCommon() . '">'
+                );
                 $messageInstance->addParamHtml('</a>');
                 /* Show error if user has configured something, notice elsewhere */
                 if (! empty($cfg['Servers'][$server]['pmadb'])) {
@@ -253,84 +222,93 @@ class HomeController extends AbstractController
 
         $this->checkRequirements();
 
-        return $this->template->render('home/index', [
+        $git = new Git($this->config);
+
+        $this->render('home/index', [
             'message' => $displayMessage ?? '',
             'partial_logout' => $partialLogout ?? '',
-            'is_git_revision' => $this->config->isGitRevision(),
+            'is_git_revision' => $git->isGitRevision(),
             'server' => $server,
             'sync_favorite_tables' => $syncFavoriteTables,
             'has_server' => $hasServer,
             'is_demo' => $cfg['DBG']['demo'],
             'has_server_selection' => $hasServerSelection ?? false,
             'server_selection' => $serverSelection ?? '',
-            'change_password' => $changePassword ?? '',
+            'has_change_password_link' => $cfg['Server']['auth_type'] !== 'config' && $cfg['ShowChgPassword'],
             'charsets' => $charsetsList ?? [],
             'language_selector' => $languageSelector,
             'theme_selection' => $themeSelection,
-            'user_preferences' => $userPreferences ?? '',
             'database_server' => $databaseServer,
             'web_server' => $webServer,
-            'php_info' => $phpInfo ?? '',
+            'show_php_info' => $cfg['ShowPhpInfo'],
             'is_version_checked' => $cfg['VersionCheck'],
             'phpmyadmin_version' => PMA_VERSION,
             'config_storage_message' => $configStorageMessage ?? '',
         ]);
     }
 
-    /**
-     * @param array $params Request parameters
-     * @return void
-     */
-    public function setTheme(array $params): void
+    public function setTheme(): void
     {
-        $this->themeManager->setActiveTheme($params['set_theme']);
+        $this->themeManager->setActiveTheme($_POST['set_theme']);
         $this->themeManager->setThemeCookie();
 
         $userPreferences = new UserPreferences();
         $preferences = $userPreferences->load();
-        $preferences['config_data']['ThemeDefault'] = $params['set_theme'];
+        $preferences['config_data']['ThemeDefault'] = $_POST['set_theme'];
         $userPreferences->save($preferences['config_data']);
+
+        $this->response->header('Location: index.php?route=/' . Url::getCommonRaw([], '&'));
     }
 
-    /**
-     * @param array $params Request parameters
-     * @return void
-     */
-    public function setCollationConnection(array $params): void
+    public function setCollationConnection(): void
     {
         $this->config->setUserValue(
             null,
             'DefaultConnectionCollation',
-            $params['collation_connection'],
+            $_POST['collation_connection'],
             'utf8mb4_unicode_ci'
         );
+
+        $this->response->header('Location: index.php?route=/' . Url::getCommonRaw([], '&'));
     }
 
-    /**
-     * @return array JSON
-     */
-    public function reloadRecentTablesList(): array
+    public function reloadRecentTablesList(): void
     {
-        return [
+        if (! $this->response->isAjax()) {
+            return;
+        }
+
+        $this->response->addJSON([
             'list' => RecentFavoriteTable::getInstance('recent')->getHtmlList(),
-        ];
+        ]);
     }
 
-    /**
-     * @return string HTML
-     */
-    public function gitRevision(): string
+    public function gitRevision(): void
     {
-        return (new GitRevision(
-            $this->response,
-            $this->config,
-            $this->template
-        ))->display();
+        if (! $this->response->isAjax()) {
+            return;
+        }
+
+        $git = new Git($this->config);
+
+        if (! $git->isGitRevision()) {
+            return;
+        }
+
+        $commit = $git->checkGitRevision();
+
+        if (! $this->config->get('PMA_VERSION_GIT') || $commit === null) {
+            $this->response->setRequestStatus(false);
+
+            return;
+        }
+
+        $commit['author']['date'] = Util::localisedDate(strtotime($commit['author']['date']));
+        $commit['committer']['date'] = Util::localisedDate(strtotime($commit['committer']['date']));
+
+        $this->render('home/git_info', $commit);
     }
 
-    /**
-     * @return void
-     */
     private function checkRequirements(): void
     {
         global $cfg, $server, $lang;
@@ -402,9 +380,10 @@ class HomeController extends AbstractController
         /**
          * Warning if using the default MySQL controluser account
          */
-        if ($server != 0
-            && isset($cfg['Server']['controluser']) && $cfg['Server']['controluser'] == 'pma'
-            && isset($cfg['Server']['controlpass']) && $cfg['Server']['controlpass'] == 'pmapass'
+        if (isset($cfg['Server']['controluser'], $cfg['Server']['controlpass'])
+            && $server != 0
+            && $cfg['Server']['controluser'] === 'pma'
+            && $cfg['Server']['controlpass'] === 'pmapass'
         ) {
             trigger_error(
                 __(
@@ -495,23 +474,27 @@ class HomeController extends AbstractController
          *
          * The data file is created while creating release by ./scripts/remove-incomplete-mo
          */
-        if (@file_exists(ROOT_PATH . 'libraries/language_stats.inc.php')) {
-            include ROOT_PATH . 'libraries/language_stats.inc.php';
-            /*
-             * This message is intentionally not translated, because we're
-             * handling incomplete translations here and focus on english
-             * speaking users.
-             */
-            if (isset($GLOBALS['language_stats'][$lang])
-                && $GLOBALS['language_stats'][$lang] < $cfg['TranslationWarningThreshold']
-            ) {
-                trigger_error(
-                    'You are using an incomplete translation, please help to make it '
-                    . 'better by [a@https://www.phpmyadmin.net/translate/'
-                    . '@_blank]contributing[/a].',
-                    E_USER_NOTICE
-                );
-            }
+        if (! @file_exists(ROOT_PATH . 'libraries/language_stats.inc.php')) {
+            return;
         }
+
+        include ROOT_PATH . 'libraries/language_stats.inc.php';
+        /*
+         * This message is intentionally not translated, because we're
+         * handling incomplete translations here and focus on english
+         * speaking users.
+         */
+        if (! isset($GLOBALS['language_stats'][$lang])
+            || $GLOBALS['language_stats'][$lang] >= $cfg['TranslationWarningThreshold']
+        ) {
+            return;
+        }
+
+        trigger_error(
+            'You are using an incomplete translation, please help to make it '
+            . 'better by [a@https://www.phpmyadmin.net/translate/'
+            . '@_blank]contributing[/a].',
+            E_USER_NOTICE
+        );
     }
 }
