@@ -1,36 +1,54 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * Holds the PhpMyAdmin\Controllers\Server\Status\StatusController
- *
- * @package PhpMyAdmin\Controllers
- */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Controllers\Server\Status;
 
+use PhpMyAdmin\DatabaseInterface;
 use PhpMyAdmin\ReplicationGui;
+use PhpMyAdmin\Response;
+use PhpMyAdmin\Server\Status\Data;
+use PhpMyAdmin\Template;
+use PhpMyAdmin\Url;
 use PhpMyAdmin\Util;
-use Throwable;
+use function implode;
 
 /**
- * Class StatusController
- * @package PhpMyAdmin\Controllers\Server\Status
+ * Object the server status page: processes, connections and traffic.
  */
 class StatusController extends AbstractController
 {
+    /** @var ReplicationGui */
+    private $replicationGui;
+
+    /** @var DatabaseInterface */
+    private $dbi;
+
     /**
-     * @param ReplicationGui $replicationGui ReplicationGui instance
-     *
-     * @return string
-     * @throws Throwable
-     * @throws \Twig\Error\LoaderError
-     * @throws \Twig\Error\RuntimeError
-     * @throws \Twig\Error\SyntaxError
+     * @param Response          $response
+     * @param Data              $data
+     * @param DatabaseInterface $dbi
      */
-    public function index(ReplicationGui $replicationGui): string
+    public function __construct($response, Template $template, $data, ReplicationGui $replicationGui, $dbi)
     {
-        global $replication_info;
+        parent::__construct($response, $template, $data);
+        $this->replicationGui = $replicationGui;
+        $this->dbi = $dbi;
+    }
+
+    public function index(): void
+    {
+        global $err_url;
+
+        $err_url = Url::getFromRoute('/');
+
+        if ($this->dbi->isSuperUser()) {
+            $this->dbi->selectDb('mysql');
+        }
+
+        $replicationInfo = $this->data->getReplicationInfo();
+        $primaryInfo = $replicationInfo->getPrimaryInfo();
+        $replicaInfo = $replicationInfo->getReplicaInfo();
 
         $traffic = [];
         $connections = [];
@@ -51,30 +69,27 @@ class StatusController extends AbstractController
 
             $connections = $this->getConnectionsInfo();
 
-            // display replication information
-            if ($replication_info['master']['status']
-                || $replication_info['slave']['status']
-            ) {
-                $replication = $this->getReplicationInfo($replicationGui);
+            if ($primaryInfo['status']) {
+                $replication .= $this->replicationGui->getHtmlForReplicationStatusTable('master');
+            }
+            if ($replicaInfo['status']) {
+                $replication .= $this->replicationGui->getHtmlForReplicationStatusTable('slave');
             }
         }
 
-        return $this->template->render('server/status/status/index', [
+        $this->render('server/status/status/index', [
             'is_data_loaded' => $this->data->dataLoaded,
             'network_traffic' => $networkTraffic ?? null,
             'uptime' => $uptime ?? null,
             'start_time' => $startTime ?? null,
             'traffic' => $traffic,
             'connections' => $connections,
-            'is_master' => $replication_info['master']['status'],
-            'is_slave' => $replication_info['slave']['status'],
+            'is_master' => $primaryInfo['status'],
+            'is_slave' => $replicaInfo['status'],
             'replication' => $replication,
         ]);
     }
 
-    /**
-     * @return int
-     */
     private function getStartTime(): int
     {
         return (int) $this->dbi->fetchValue(
@@ -233,25 +248,4 @@ class StatusController extends AbstractController
             ],
         ];
     }
-
-    /**
-     * @param ReplicationGui $replicationGui ReplicationGui instance
-     *
-     * @return string
-     */
-    private function getReplicationInfo(ReplicationGui $replicationGui): string
-    {
-        global $replication_info, $replication_types;
-
-        $output = '';
-        foreach ($replication_types as $type) {
-            if (isset($replication_info[$type]['status'])
-                && $replication_info[$type]['status']
-            ) {
-                $output .= $replicationGui->getHtmlForReplicationStatusTable($type);
-            }
-        }
-
-        return $output;
-    }
 }
