@@ -1,22 +1,11 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * holds the PhpMyAdmin\Database\DatabaseList class
- *
- * @package PhpMyAdmin
- *
- */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Database;
 
 use PhpMyAdmin\ListDatabase;
 
-/**
- * holds the DatabaseList class
- *
- * @package PhpMyAdmin
- */
 class DatabaseList
 {
     /**
@@ -29,10 +18,11 @@ class DatabaseList
     /**
      * magic access to protected/inaccessible members/properties
      *
+     * @see https://secure.php.net/language.oop5.overloading
+     *
      * @param string $param parameter name
      *
      * @return mixed
-     * @see https://www.php.net/language.oop5.overloading
      */
     public function __get($param)
     {
@@ -46,12 +36,10 @@ class DatabaseList
 
     /**
      * Accessor to PMA::$databases
-     *
-     * @return ListDatabase
      */
-    public function getDatabaseList()
+    public function getDatabaseList(): ListDatabase
     {
-        if (null === $this->databases) {
+        if ($this->databases === null) {
             $this->databases = new ListDatabase();
         }
 
