@@ -1,31 +1,60 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * function for the main export logic
- *
- * @package PhpMyAdmin
  */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin;
 
+use PhpMyAdmin\Controllers\Database\ExportController as DatabaseExportController;
+use PhpMyAdmin\Controllers\Server\ExportController as ServerExportController;
+use PhpMyAdmin\Controllers\Table\ExportController as TableExportController;
 use PhpMyAdmin\Plugins\ExportPlugin;
 use PhpMyAdmin\Plugins\SchemaPlugin;
+use function array_merge_recursive;
+use function error_get_last;
+use function fclose;
+use function file_exists;
+use function fopen;
+use function function_exists;
+use function fwrite;
+use function gzencode;
+use function header;
+use function htmlentities;
+use function htmlspecialchars;
+use function implode;
+use function in_array;
+use function ini_get;
+use function is_array;
+use function is_file;
+use function is_numeric;
+use function is_object;
+use function is_string;
+use function is_writable;
+use function mb_strlen;
+use function mb_strpos;
+use function mb_strtolower;
+use function mb_substr;
+use function ob_list_handlers;
+use function preg_match;
+use function preg_replace;
+use function strlen;
+use function strtolower;
+use function substr;
+use function time;
+use function trim;
+use function urlencode;
 
 /**
  * PhpMyAdmin\Export class
- *
- * @package PhpMyAdmin
  */
 class Export
 {
-    /**
-     * @var DatabaseInterface
-     */
+    /** @var DatabaseInterface */
     private $dbi;
 
     /**
-     * Export constructor.
      * @param DatabaseInterface $dbi DatabaseInterface instance
      */
     public function __construct($dbi)
@@ -35,22 +64,20 @@ class Export
 
     /**
      * Sets a session variable upon a possible fatal error during export
-     *
-     * @return void
      */
     public function shutdown(): void
     {
         $error = error_get_last();
-        if ($error != null && mb_strpos($error['message'], "execution time")) {
-            //set session variable to check if there was error while exporting
-            $_SESSION['pma_export_error'] = $error['message'];
+        if ($error == null || ! mb_strpos($error['message'], 'execution time')) {
+            return;
         }
+
+        //set session variable to check if there was error while exporting
+        $_SESSION['pma_export_error'] = $error['message'];
     }
 
     /**
      * Detect ob_gzhandler
-     *
-     * @return bool
      */
     public function isGzHandlerEnabled(): bool
     {
@@ -99,7 +126,7 @@ class Export
             $line = Encoding::kanjiStrConv(
                 $line,
                 $GLOBALS['knjenc'],
-                isset($GLOBALS['xkana']) ? $GLOBALS['xkana'] : ''
+                $GLOBALS['xkana'] ?? ''
             );
         }
 
@@ -107,7 +134,7 @@ class Export
         if ($GLOBALS['buffer_needed']) {
             $dump_buffer .= $line;
             if ($GLOBALS['onfly_compression']) {
-                $dump_buffer_len += strlen($line);
+                $dump_buffer_len += strlen((string) $line);
 
                 if ($dump_buffer_len > $GLOBALS['memory_limit']) {
                     if ($GLOBALS['output_charset_conversion']) {
@@ -117,7 +144,7 @@ class Export
                             $dump_buffer
                         );
                     }
-                    if ($GLOBALS['compression'] == 'gzip'
+                    if ($GLOBALS['compression'] === 'gzip'
                         && $this->gzencodeNeeded()
                     ) {
                         // as a gzipped file
@@ -125,14 +152,15 @@ class Export
                         $dump_buffer = gzencode($dump_buffer);
                     }
                     if ($GLOBALS['save_on_server']) {
-                        $write_result = @fwrite($GLOBALS['file_handle'], $dump_buffer);
+                        $write_result = @fwrite($GLOBALS['file_handle'], (string) $dump_buffer);
                         // Here, use strlen rather than mb_strlen to get the length
                         // in bytes to compare against the number of bytes written.
-                        if ($write_result != strlen($dump_buffer)) {
+                        if ($write_result != strlen((string) $dump_buffer)) {
                             $GLOBALS['message'] = Message::error(
                                 __('Insufficient space to save the file %s.')
                             );
                             $GLOBALS['message']->addParam($save_filename);
+
                             return false;
                         }
                     } else {
@@ -146,7 +174,7 @@ class Export
                 if ($time_start >= $time_now + 30) {
                     $time_start = $time_now;
                     header('X-pmaPing: Pong');
-                } // end if
+                }
             }
         } elseif ($GLOBALS['asfile']) {
             if ($GLOBALS['output_charset_conversion']) {
@@ -156,36 +184,38 @@ class Export
                     $line
                 );
             }
-            if ($GLOBALS['save_on_server'] && mb_strlen($line) > 0) {
+            if ($GLOBALS['save_on_server'] && mb_strlen((string) $line) > 0) {
                 if ($GLOBALS['file_handle'] !== null) {
-                    $write_result = @fwrite($GLOBALS['file_handle'], $line);
+                    $write_result = @fwrite($GLOBALS['file_handle'], (string) $line);
                 } else {
                     $write_result = false;
                 }
                 // Here, use strlen rather than mb_strlen to get the length
                 // in bytes to compare against the number of bytes written.
                 if (! $write_result
-                    || $write_result != strlen($line)
+                    || $write_result != strlen((string) $line)
                 ) {
                     $GLOBALS['message'] = Message::error(
                         __('Insufficient space to save the file %s.')
                     );
                     $GLOBALS['message']->addParam($save_filename);
+
                     return false;
                 }
                 $time_now = time();
                 if ($time_start >= $time_now + 30) {
                     $time_start = $time_now;
                     header('X-pmaPing: Pong');
-                } // end if
+                }
             } else {
                 // We export as file - output normally
                 echo $line;
             }
         } else {
             // We export as html - replace special chars
-            echo htmlspecialchars($line);
+            echo htmlspecialchars((string) $line);
         }
+
         return true;
     }
 
@@ -228,17 +258,17 @@ class Export
      */
     public function getMemoryLimit(): int
     {
-        $memory_limit = trim(ini_get('memory_limit'));
+        $memory_limit = trim((string) ini_get('memory_limit'));
         $memory_limit_num = (int) substr($memory_limit, 0, -1);
         $lowerLastChar = strtolower(substr($memory_limit, -1));
         // 2 MB as default
-        if (empty($memory_limit) || '-1' == $memory_limit) {
+        if (empty($memory_limit) || $memory_limit == '-1') {
             $memory_limit = 2 * 1024 * 1024;
-        } elseif ($lowerLastChar == 'm') {
+        } elseif ($lowerLastChar === 'm') {
             $memory_limit = $memory_limit_num * 1024 * 1024;
-        } elseif ($lowerLastChar == 'k') {
+        } elseif ($lowerLastChar === 'k') {
             $memory_limit = $memory_limit_num * 1024;
-        } elseif ($lowerLastChar == 'g') {
+        } elseif ($lowerLastChar === 'g') {
             $memory_limit = $memory_limit_num * 1024 * 1024 * 1024;
         } else {
             $memory_limit = (int) $memory_limit;
@@ -253,9 +283,57 @@ class Export
 
         // Some memory is needed for compression, assume 1/3
         $memory_limit /= 8;
+
         return $memory_limit;
     }
 
+    /**
+     * Returns the filename and MIME type for a compression and an export plugin
+     *
+     * @param ExportPlugin $exportPlugin the export plugin
+     * @param string       $compression  compression asked
+     * @param string       $filename     the filename
+     *
+     * @return string[]    the filename and mime type
+     */
+    public function getFinalFilenameAndMimetypeForFilename(
+        ExportPlugin $exportPlugin,
+        string $compression,
+        string $filename
+    ): array {
+        // Grab basic dump extension and mime type
+        // Check if the user already added extension;
+        // get the substring where the extension would be if it was included
+        $extensionStartPos = mb_strlen($filename) - mb_strlen(
+            $exportPlugin->getProperties()->getExtension()
+        ) - 1;
+        $userExtension = mb_substr(
+            $filename,
+            $extensionStartPos,
+            mb_strlen($filename)
+        );
+        $requiredExtension = '.' . $exportPlugin->getProperties()->getExtension();
+        if (mb_strtolower($userExtension) != $requiredExtension) {
+            $filename  .= $requiredExtension;
+        }
+        $mime_type  = $exportPlugin->getProperties()->getMimeType();
+
+        // If dump is going to be compressed, set correct mime_type and add
+        // compression to extension
+        if ($compression === 'gzip') {
+            $filename  .= '.gz';
+            $mime_type = 'application/x-gzip';
+        } elseif ($compression === 'zip') {
+            $filename  .= '.zip';
+            $mime_type = 'application/zip';
+        }
+
+        return [
+            $filename,
+            $mime_type,
+        ];
+    }
+
     /**
      * Return the filename and MIME type for export file
      *
@@ -274,7 +352,7 @@ class Export
         string $compression,
         string $filename_template
     ): array {
-        if ($export_type == 'server') {
+        if ($export_type === 'server') {
             if (! empty($remember_template)) {
                 $GLOBALS['PMA_Config']->setUserValue(
                     'pma_server_filename_template',
@@ -282,7 +360,7 @@ class Export
                     $filename_template
                 );
             }
-        } elseif ($export_type == 'database') {
+        } elseif ($export_type === 'database') {
             if (! empty($remember_template)) {
                 $GLOBALS['PMA_Config']->setUserValue(
                     'pma_db_filename_template',
@@ -290,6 +368,14 @@ class Export
                     $filename_template
                 );
             }
+        } elseif ($export_type === 'raw') {
+            if (! empty($remember_template)) {
+                $GLOBALS['PMA_Config']->setUserValue(
+                    'pma_raw_filename_template',
+                    'Export/file_template_raw',
+                    $filename_template
+                );
+            }
         } else {
             if (! empty($remember_template)) {
                 $GLOBALS['PMA_Config']->setUserValue(
@@ -302,45 +388,20 @@ class Export
         $filename = Util::expandUserString($filename_template);
         // remove dots in filename (coming from either the template or already
         // part of the filename) to avoid a remote code execution vulnerability
-        $filename = Sanitize::sanitizeFilename($filename, $replaceDots = true);
+        $filename = Sanitize::sanitizeFilename($filename, true);
 
-        // Grab basic dump extension and mime type
-        // Check if the user already added extension;
-        // get the substring where the extension would be if it was included
-        $extension_start_pos = mb_strlen($filename) - mb_strlen(
-            $export_plugin->getProperties()->getExtension()
-        ) - 1;
-        $user_extension = mb_substr(
-            $filename,
-            $extension_start_pos,
-            mb_strlen($filename)
+        return $this->getFinalFilenameAndMimetypeForFilename(
+            $export_plugin,
+            $compression,
+            $filename
         );
-        $required_extension = "." . $export_plugin->getProperties()->getExtension();
-        if (mb_strtolower($user_extension) != $required_extension) {
-            $filename  .= $required_extension;
-        }
-        $mime_type  = $export_plugin->getProperties()->getMimeType();
-
-        // If dump is going to be compressed, set correct mime_type and add
-        // compression to extension
-        if ($compression == 'gzip') {
-            $filename  .= '.gz';
-            $mime_type = 'application/x-gzip';
-        } elseif ($compression == 'zip') {
-            $filename  .= '.zip';
-            $mime_type = 'application/zip';
-        }
-        return [
-            $filename,
-            $mime_type,
-        ];
     }
 
     /**
      * Open the export file
      *
-     * @param string  $filename     the export filename
-     * @param boolean $quick_export whether it's a quick export or not
+     * @param string $filename     the export filename
+     * @param bool   $quick_export whether it's a quick export or not
      *
      * @return array the full save filename, possible message and the file handle
      */
@@ -351,7 +412,7 @@ class Export
         $doNotSaveItOver = true;
 
         if (isset($_POST['quick_export_onserver_overwrite'])) {
-            $doNotSaveItOver = $_POST['quick_export_onserver_overwrite'] != 'saveitover';
+            $doNotSaveItOver = $_POST['quick_export_onserver_overwrite'] !== 'saveitover';
         }
 
         $save_filename = Util::userDir($GLOBALS['cfg']['SaveDir'])
@@ -377,15 +438,20 @@ class Export
                 )
             );
             $message->addParam($save_filename);
-        } elseif (! $file_handle = @fopen($save_filename, 'w')) {
-            $message = Message::error(
-                __(
-                    'The web server does not have permission '
-                    . 'to save the file %s.'
-                )
-            );
-            $message->addParam($save_filename);
+        } else {
+            $file_handle = @fopen($save_filename, 'w');
+
+            if ($file_handle === false) {
+                $message = Message::error(
+                    __(
+                        'The web server does not have permission '
+                        . 'to save the file %s.'
+                    )
+                );
+                $message->addParam($save_filename);
+            }
         }
+
         return [
             $save_filename,
             $message,
@@ -426,6 +492,7 @@ class Export
                 [$save_filename]
             );
         }
+
         return $message;
     }
 
@@ -440,14 +507,15 @@ class Export
      */
     public function compress($dump_buffer, string $compression, string $filename)
     {
-        if ($compression == 'zip' && function_exists('gzcompress')) {
+        if ($compression === 'zip' && function_exists('gzcompress')) {
             $zipExtension = new ZipExtension();
             $filename = substr($filename, 0, -4); // remove extension (.zip)
             $dump_buffer = $zipExtension->createFile($dump_buffer, $filename);
-        } elseif ($compression == 'gzip' && $this->gzencodeNeeded()) {
+        } elseif ($compression === 'gzip' && $this->gzencodeNeeded() && is_string($dump_buffer)) {
             // without the optional parameter level because it bugs
             $dump_buffer = gzencode($dump_buffer);
         }
+
         return $dump_buffer;
     }
 
@@ -455,10 +523,8 @@ class Export
      * Saves the dump_buffer for a particular table in an array
      * Used in separate files export
      *
-     * @param string  $object_name the name of current object to be stored
-     * @param boolean $append      optional boolean to append to an existing index or not
-     *
-     * @return void
+     * @param string $object_name the name of current object to be stored
+     * @param bool   $append      optional boolean to append to an existing index or not
      */
     public function saveObjectInBuffer(string $object_name, bool $append = false): void
     {
@@ -498,12 +564,12 @@ class Export
          * (store in a variable to also display after the textarea)
          */
         $back_button = '<p id="export_back_button">[ <a href="';
-        if ($export_type == 'server') {
-            $back_button .= 'server_export.php" data-post="' . Url::getCommon([], '');
-        } elseif ($export_type == 'database') {
-            $back_button .= 'db_export.php" data-post="' . Url::getCommon(['db' => $db], '');
+        if ($export_type === 'server') {
+            $back_button .= Url::getFromRoute('/server/export') . '" data-post="' . Url::getCommon([], '');
+        } elseif ($export_type === 'database') {
+            $back_button .= Url::getFromRoute('/database/export') . '" data-post="' . Url::getCommon(['db' => $db], '');
         } else {
-            $back_button .= 'tbl_export.php" data-post="' . Url::getCommon(
+            $back_button .= Url::getFromRoute('/table/export') . '" data-post="' . Url::getCommon(
                 [
                     'db' => $db,
                     'table' => $table,
@@ -513,7 +579,7 @@ class Export
         }
 
         // Convert the multiple select elements from an array to a string
-        if ($export_type == 'database') {
+        if ($export_type === 'database') {
             $structOrDataForced = empty($_POST['structure_or_data_forced']);
             if ($structOrDataForced && ! isset($_POST['table_structure'])) {
                 $_POST['table_structure'] = [];
@@ -524,22 +590,27 @@ class Export
         }
 
         foreach ($_POST as $name => $value) {
-            if (! is_array($value)) {
-                $back_button .= '&amp;' . urlencode((string) $name) . '=' . urlencode((string) $value);
+            if (is_array($value)) {
+                continue;
             }
+
+            $back_button .= '&amp;' . urlencode((string) $name) . '=' . urlencode((string) $value);
         }
         $back_button .= '&amp;repopulate=1">' . __('Back') . '</a> ]</p>';
         $html .= '<br>';
         $html .= $back_button;
-        $refreshButton = '<form id="export_refresh_form" method="POST" action="export.php" class="disableAjax">';
-        $refreshButton .= '[ <a class="disableAjax" onclick="$(this).parent().submit()">' . __('Refresh') . '</a> ]';
+        $refreshButton = '<form id="export_refresh_form" method="POST" action="'
+            . Url::getFromRoute('/export') . '" class="disableAjax">';
+        $refreshButton .= '[ <a class="disableAjax" id="export_refresh_btn">' . __('Refresh') . '</a> ]';
         foreach ($_POST as $name => $value) {
             if (is_array($value)) {
                 foreach ($value as $val) {
-                    $refreshButton .= '<input type="hidden" name="' . htmlentities((string) $name) . '[]" value="' . htmlentities((string) $val) . '">';
+                    $refreshButton .= '<input type="hidden" name="' . htmlentities((string) $name)
+                        . '[]" value="' . htmlentities((string) $val) . '">';
                 }
             } else {
-                $refreshButton .= '<input type="hidden" name="' . htmlentities((string) $name) . '" value="' . htmlentities((string) $value) . '">';
+                $refreshButton .= '<input type="hidden" name="' . htmlentities((string) $name)
+                    . '" value="' . htmlentities((string) $value) . '">';
             }
         }
         $refreshButton .= '</form>';
@@ -571,8 +642,6 @@ class Export
      * @param bool         $do_dates        whether to add dates
      * @param array        $aliases         alias information for db/table/column
      * @param string       $separate_files  whether it is a separate-files export
-     *
-     * @return void
      */
     public function exportServer(
         $db_select,
@@ -589,37 +658,41 @@ class Export
         string $separate_files
     ): void {
         if (! empty($db_select)) {
-            $tmp_select = implode($db_select, '|');
+            $tmp_select = implode('|', $db_select);
             $tmp_select = '|' . $tmp_select . '|';
         }
         // Walk over databases
         foreach ($GLOBALS['dblist']->databases as $current_db) {
-            if (isset($tmp_select)
-                && mb_strpos(' ' . $tmp_select, '|' . $current_db . '|')
+            if (! isset($tmp_select)
+                || ! mb_strpos(' ' . $tmp_select, '|' . $current_db . '|')
             ) {
-                $tables = $this->dbi->getTables($current_db);
-                $this->exportDatabase(
-                    $current_db,
-                    $tables,
-                    $whatStrucOrData,
-                    $tables,
-                    $tables,
-                    $export_plugin,
-                    $crlf,
-                    $err_url,
-                    $export_type,
-                    $do_relation,
-                    $do_comments,
-                    $do_mime,
-                    $do_dates,
-                    $aliases,
-                    $separate_files == 'database' ? $separate_files : ''
-                );
-                if ($separate_files == 'server') {
-                    $this->saveObjectInBuffer($current_db);
-                }
+                continue;
             }
-        } // end foreach database
+
+            $tables = $this->dbi->getTables($current_db);
+            $this->exportDatabase(
+                $current_db,
+                $tables,
+                $whatStrucOrData,
+                $tables,
+                $tables,
+                $export_plugin,
+                $crlf,
+                $err_url,
+                $export_type,
+                $do_relation,
+                $do_comments,
+                $do_mime,
+                $do_dates,
+                $aliases,
+                $separate_files === 'database' ? $separate_files : ''
+            );
+            if ($separate_files !== 'server') {
+                continue;
+            }
+
+            $this->saveObjectInBuffer($current_db);
+        }
     }
 
     /**
@@ -640,8 +713,6 @@ class Export
      * @param bool         $do_dates        whether to add dates
      * @param array        $aliases         Alias information for db/table/column
      * @param string       $separate_files  whether it is a separate-files export
-     *
-     * @return void
      */
     public function exportDatabase(
         string $db,
@@ -669,17 +740,17 @@ class Export
         if (! $export_plugin->exportDBCreate($db, $export_type, $db_alias)) {
             return;
         }
-        if ($separate_files == 'database') {
+        if ($separate_files === 'database') {
             $this->saveObjectInBuffer('database', true);
         }
 
-        if (($GLOBALS['sql_structure_or_data'] == 'structure'
-            || $GLOBALS['sql_structure_or_data'] == 'structure_and_data')
+        if (($GLOBALS['sql_structure_or_data'] === 'structure'
+            || $GLOBALS['sql_structure_or_data'] === 'structure_and_data')
             && isset($GLOBALS['sql_procedure_function'])
         ) {
             $export_plugin->exportRoutines($db, $aliases);
 
-            if ($separate_files == 'database') {
+            if ($separate_files === 'database') {
                 $this->saveObjectInBuffer('routines');
             }
         }
@@ -694,8 +765,8 @@ class Export
             if ($is_view) {
                 $views[] = $table;
             }
-            if (($whatStrucOrData == 'structure'
-                || $whatStrucOrData == 'structure_and_data')
+            if (($whatStrucOrData === 'structure'
+                || $whatStrucOrData === 'structure_and_data')
                 && in_array($table, $table_structure)
             ) {
                 // for a view, export a stand-in definition of the table
@@ -732,7 +803,7 @@ class Export
 
                         $size = $this->dbi->fetchValue($query);
                         //Converting the size to MB
-                        $size = ($size / 1024) / 1024;
+                        $size /= 1024 / 1024;
                         if ($size > $table_size) {
                             continue;
                         }
@@ -756,7 +827,7 @@ class Export
                 }
             }
             // if this is a view or a merge table, don't export data
-            if (($whatStrucOrData == 'data' || $whatStrucOrData == 'structure_and_data')
+            if (($whatStrucOrData === 'data' || $whatStrucOrData === 'structure_and_data')
                 && in_array($table, $table_data)
                 && ! $is_view
             ) {
@@ -780,22 +851,57 @@ class Export
             }
 
             // this buffer was filled, we save it and go to the next one
-            if ($separate_files == 'database') {
+            if ($separate_files === 'database') {
                 $this->saveObjectInBuffer('table_' . $table);
             }
 
             // now export the triggers (needs to be done after the data because
             // triggers can modify already imported tables)
-            if (isset($GLOBALS['sql_create_trigger']) && ($whatStrucOrData == 'structure'
-                || $whatStrucOrData == 'structure_and_data')
-                && in_array($table, $table_structure)
+            if (! isset($GLOBALS['sql_create_trigger']) || ($whatStrucOrData !== 'structure'
+                && $whatStrucOrData !== 'structure_and_data')
+                || ! in_array($table, $table_structure)
             ) {
+                continue;
+            }
+
+            if (! $export_plugin->exportStructure(
+                $db,
+                $table,
+                $crlf,
+                $err_url,
+                'triggers',
+                $export_type,
+                $do_relation,
+                $do_comments,
+                $do_mime,
+                $do_dates,
+                $aliases
+            )) {
+                break;
+            }
+
+            if ($separate_files !== 'database') {
+                continue;
+            }
+
+            $this->saveObjectInBuffer('table_' . $table, true);
+        }
+
+        if (isset($GLOBALS['sql_create_view'])) {
+            foreach ($views as $view) {
+                // no data export for a view
+                if ($whatStrucOrData !== 'structure'
+                    && $whatStrucOrData !== 'structure_and_data'
+                ) {
+                    continue;
+                }
+
                 if (! $export_plugin->exportStructure(
                     $db,
-                    $table,
+                    $view,
                     $crlf,
                     $err_url,
-                    'triggers',
+                    'create_view',
                     $export_type,
                     $do_relation,
                     $do_comments,
@@ -806,38 +912,11 @@ class Export
                     break;
                 }
 
-                if ($separate_files == 'database') {
-                    $this->saveObjectInBuffer('table_' . $table, true);
+                if ($separate_files !== 'database') {
+                    continue;
                 }
-            }
-        }
 
-        if (isset($GLOBALS['sql_create_view'])) {
-            foreach ($views as $view) {
-                // no data export for a view
-                if ($whatStrucOrData == 'structure'
-                    || $whatStrucOrData == 'structure_and_data'
-                ) {
-                    if (! $export_plugin->exportStructure(
-                        $db,
-                        $view,
-                        $crlf,
-                        $err_url,
-                        'create_view',
-                        $export_type,
-                        $do_relation,
-                        $do_comments,
-                        $do_mime,
-                        $do_dates,
-                        $aliases
-                    )) {
-                        break;
-                    }
-
-                    if ($separate_files == 'database') {
-                        $this->saveObjectInBuffer('view_' . $view);
-                    }
-                }
+                $this->saveObjectInBuffer('view_' . $view);
             }
         }
 
@@ -852,24 +931,66 @@ class Export
             $metadataTypes = $this->getMetadataTypes();
             $export_plugin->exportMetadata($db, $tables, $metadataTypes);
 
-            if ($separate_files == 'database') {
+            if ($separate_files === 'database') {
                 $this->saveObjectInBuffer('metadata');
             }
         }
 
-        if ($separate_files == 'database') {
+        if ($separate_files === 'database') {
             $this->saveObjectInBuffer('extra');
         }
 
-        if (($GLOBALS['sql_structure_or_data'] == 'structure'
-            || $GLOBALS['sql_structure_or_data'] == 'structure_and_data')
-            && isset($GLOBALS['sql_procedure_function'])
+        if (($GLOBALS['sql_structure_or_data'] !== 'structure'
+            && $GLOBALS['sql_structure_or_data'] !== 'structure_and_data')
+            || ! isset($GLOBALS['sql_procedure_function'])
         ) {
-            $export_plugin->exportEvents($db);
+            return;
+        }
 
-            if ($separate_files == 'database') {
-                $this->saveObjectInBuffer('events');
-            }
+        $export_plugin->exportEvents($db);
+
+        if ($separate_files !== 'database') {
+            return;
+        }
+
+        $this->saveObjectInBuffer('events');
+    }
+
+    /**
+     * Export a raw query
+     *
+     * @param string       $whatStrucOrData whether to export structure for each table or raw
+     * @param ExportPlugin $export_plugin   the selected export plugin
+     * @param string       $crlf            end of line character(s)
+     * @param string       $err_url         the URL in case of error
+     * @param string       $sql_query       the query to be executed
+     * @param string       $export_type     the export type
+     */
+    public static function exportRaw(
+        string $whatStrucOrData,
+        ExportPlugin $export_plugin,
+        string $crlf,
+        string $err_url,
+        string $sql_query,
+        string $export_type
+    ): void {
+        // In case the we need to dump just the raw query
+        if ($whatStrucOrData !== 'raw') {
+            return;
+        }
+
+        if (! $export_plugin->exportRawQuery(
+            $err_url,
+            $sql_query,
+            $crlf
+        )) {
+            $GLOBALS['message'] = Message::error(
+                // phpcs:disable Generic.Files.LineLength.TooLong
+                /* l10n: A query written by the user is a "raw query" that could be using no tables or databases in particular */
+                __('Exporting a raw query is not supported for this export method.')
+            );
+
+            return;
         }
     }
 
@@ -892,8 +1013,6 @@ class Export
      * @param string       $limit_from      starting limit
      * @param string       $sql_query       query for which exporting is requested
      * @param array        $aliases         Alias information for db/table/column
-     *
-     * @return void
      */
     public function exportTable(
         string $db,
@@ -932,8 +1051,8 @@ class Export
 
         $_table = new Table($table, $db);
         $is_view = $_table->isView();
-        if ($whatStrucOrData == 'structure'
-            || $whatStrucOrData == 'structure_and_data'
+        if ($whatStrucOrData === 'structure'
+            || $whatStrucOrData === 'structure_and_data'
         ) {
             if ($is_view) {
                 if (isset($GLOBALS['sql_create_view'])) {
@@ -974,8 +1093,8 @@ class Export
         // If this is an export of a single view, we have to export data;
         // for example, a PDF report
         // if it is a merge table, no data is exported
-        if ($whatStrucOrData == 'data'
-            || $whatStrucOrData == 'structure_and_data'
+        if ($whatStrucOrData === 'data'
+            || $whatStrucOrData === 'structure_and_data'
         ) {
             if (! empty($sql_query)) {
                 // only preg_replace if needed
@@ -1007,8 +1126,8 @@ class Export
         }
         // now export the triggers (needs to be done after the data because
         // triggers can modify already imported tables)
-        if (isset($GLOBALS['sql_create_trigger']) && ($whatStrucOrData == 'structure'
-            || $whatStrucOrData == 'structure_and_data')
+        if (isset($GLOBALS['sql_create_trigger']) && ($whatStrucOrData === 'structure'
+            || $whatStrucOrData === 'structure_and_data')
         ) {
             if (! $export_plugin->exportStructure(
                 $db,
@@ -1030,37 +1149,45 @@ class Export
             return;
         }
 
-        if (isset($GLOBALS['sql_metadata'])) {
-            // Types of metadata to export.
-            // In the future these can be allowed to be selected by the user
-            $metadataTypes = $this->getMetadataTypes();
-            $export_plugin->exportMetadata($db, $table, $metadataTypes);
+        if (! isset($GLOBALS['sql_metadata'])) {
+            return;
         }
+
+        // Types of metadata to export.
+        // In the future these can be allowed to be selected by the user
+        $metadataTypes = $this->getMetadataTypes();
+        $export_plugin->exportMetadata($db, $table, $metadataTypes);
     }
 
     /**
      * Loads correct page after doing export
-     *
-     * @param string $db          the database name
-     * @param string $table       the table name
-     * @param string $export_type Export type
-     *
-     * @return void
      */
-    public function showPage(string $db, string $table, string $export_type): void
+    public function showPage(string $exportType): void
     {
-        global $cfg;
-        if ($export_type == 'server') {
-            $active_page = 'server_export.php';
-            include_once ROOT_PATH . 'server_export.php';
-        } elseif ($export_type == 'database') {
-            $active_page = 'db_export.php';
-            include_once ROOT_PATH . 'db_export.php';
-        } else {
-            $active_page = 'tbl_export.php';
-            include_once ROOT_PATH . 'tbl_export.php';
+        global $active_page, $containerBuilder;
+
+        if ($exportType === 'server') {
+            $active_page = Url::getFromRoute('/server/export');
+            /** @var ServerExportController $controller */
+            $controller = $containerBuilder->get(ServerExportController::class);
+            $controller->index();
+
+            return;
         }
-        exit;
+
+        if ($exportType === 'database') {
+            $active_page = Url::getFromRoute('/database/export');
+            /** @var DatabaseExportController $controller */
+            $controller = $containerBuilder->get(DatabaseExportController::class);
+            $controller->index();
+
+            return;
+        }
+
+        $active_page = Url::getFromRoute('/table/export');
+        /** @var TableExportController $controller */
+        $controller = $containerBuilder->get(TableExportController::class);
+        $controller->index();
     }
 
     /**
@@ -1104,16 +1231,19 @@ class Export
                     continue;
                 }
                 foreach ($tbl['columns'] as $col => $col_as) {
-                    if (isset($col_as) && is_array($col_as)) {
-                        $val1 = $col_as[0];
-                        $val2 = $col_as[1];
-                        // Use aliases2 alias if non empty
-                        $aliases[$db_name]['tables'][$tbl_name]['columns'][$col]
-                            = empty($val2) ? $val1 : $val2;
+                    if (! isset($col_as) || ! is_array($col_as)) {
+                        continue;
                     }
+
+                    $val1 = $col_as[0];
+                    $val2 = $col_as[1];
+                    // Use aliases2 alias if non empty
+                    $aliases[$db_name]['tables'][$tbl_name]['columns'][$col]
+                        = empty($val2) ? $val1 : $val2;
                 }
             }
         }
+
         return $aliases;
     }
 
@@ -1126,15 +1256,16 @@ class Export
      *
      * @return mixed result of the query
      */
-    public function lockTables(string $db, array $tables, string $lockType = "WRITE")
+    public function lockTables(string $db, array $tables, string $lockType = 'WRITE')
     {
         $locks = [];
         foreach ($tables as $table) {
-            $locks[] = Util::backquote($db) . "."
-                . Util::backquote($table) . " " . $lockType;
+            $locks[] = Util::backquote($db) . '.'
+                . Util::backquote($table) . ' ' . $lockType;
         }
 
-        $sql = "LOCK TABLES " . implode(", ", $locks);
+        $sql = 'LOCK TABLES ' . implode(', ', $locks);
+
         return $this->dbi->tryQuery($sql);
     }
 
@@ -1145,7 +1276,7 @@ class Export
      */
     public function unlockTables()
     {
-        return $this->dbi->tryQuery("UNLOCK TABLES");
+        return $this->dbi->tryQuery('UNLOCK TABLES');
     }
 
     /**
@@ -1191,8 +1322,6 @@ class Export
      * call and include the appropriate Schema Class depending on $export_type
      *
      * @param string|null $export_type format of the export
-     *
-     * @return void
      */
     public function processExportSchema(?string $export_type): void
     {
@@ -1209,7 +1338,7 @@ class Export
         // get the specific plugin
         /** @var SchemaPlugin $export_plugin */
         $export_plugin = Plugins::getPlugin(
-            "schema",
+            'schema',
             $export_type,
             'libraries/classes/Plugins/Schema/'
         );
