@@ -1,20 +1,27 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Used to render the header of PMA's pages
- *
- * @package PhpMyAdmin
  */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin;
 
+use PhpMyAdmin\Html\Generator;
 use PhpMyAdmin\Navigation\Navigation;
+use function defined;
+use function gmdate;
+use function header;
+use function htmlspecialchars;
+use function implode;
+use function ini_get;
+use function is_bool;
+use function strlen;
+use function strtolower;
+use function urlencode;
 
 /**
  * Class used to output the HTTP and HTML headers
- *
- * @package PhpMyAdmin
  */
 class Header
 {
@@ -24,77 +31,77 @@ class Header
      * @access private
      * @var Scripts
      */
-    private $_scripts;
+    private $scripts;
     /**
      * PhpMyAdmin\Console instance
      *
      * @access private
      * @var Console
      */
-    private $_console;
+    private $console;
     /**
      * Menu instance
      *
      * @access private
      * @var Menu
      */
-    private $_menu;
+    private $menu;
     /**
      * Whether to offer the option of importing user settings
      *
      * @access private
      * @var bool
      */
-    private $_userprefsOfferImport;
+    private $userprefsOfferImport;
     /**
      * The page title
      *
      * @access private
      * @var string
      */
-    private $_title;
+    private $title;
     /**
      * The value for the id attribute for the body tag
      *
      * @access private
      * @var string
      */
-    private $_bodyId;
+    private $bodyId;
     /**
      * Whether to show the top menu
      *
      * @access private
      * @var bool
      */
-    private $_menuEnabled;
+    private $menuEnabled;
     /**
      * Whether to show the warnings
      *
      * @access private
      * @var bool
      */
-    private $_warningsEnabled;
+    private $warningsEnabled;
     /**
      * Whether the page is in 'print view' mode
      *
      * @access private
      * @var bool
      */
-    private $_isPrintView;
+    private $isPrintView;
     /**
      * Whether we are servicing an ajax request.
      *
      * @access private
      * @var bool
      */
-    private $_isAjax;
+    private $isAjax;
     /**
      * Whether to display anything
      *
      * @access private
      * @var bool
      */
-    private $_isEnabled;
+    private $isEnabled;
     /**
      * Whether the HTTP headers (and possibly some HTML)
      * have already been sent to the browser
@@ -102,16 +109,12 @@ class Header
      * @access private
      * @var bool
      */
-    private $_headerIsSent;
+    private $headerIsSent;
 
-    /**
-     * @var UserPreferences
-     */
+    /** @var UserPreferences */
     private $userPreferences;
 
-    /**
-     * @var Template
-     */
+    /** @var Template */
     private $template;
 
     /**
@@ -119,33 +122,33 @@ class Header
      */
     public function __construct()
     {
+        global $db, $table;
+
         $this->template = new Template();
 
-        $this->_isEnabled = true;
-        $this->_isAjax = false;
-        $this->_bodyId = '';
-        $this->_title = '';
-        $this->_console = new Console();
-        $db = strlen($GLOBALS['db']) ? $GLOBALS['db'] : '';
-        $table = strlen($GLOBALS['table']) ? $GLOBALS['table'] : '';
-        $this->_menu = new Menu(
-            $db,
-            $table
+        $this->isEnabled = true;
+        $this->isAjax = false;
+        $this->bodyId = '';
+        $this->title = '';
+        $this->console = new Console();
+        $this->menu = new Menu(
+            $db ?? '',
+            $table ?? ''
         );
-        $this->_menuEnabled = true;
-        $this->_warningsEnabled = true;
-        $this->_isPrintView = false;
-        $this->_scripts = new Scripts();
-        $this->_addDefaultScripts();
-        $this->_headerIsSent = false;
+        $this->menuEnabled = true;
+        $this->warningsEnabled = true;
+        $this->isPrintView = false;
+        $this->scripts = new Scripts();
+        $this->addDefaultScripts();
+        $this->headerIsSent = false;
         // if database storage for user preferences is transient,
         // offer to load exported settings from localStorage
         // (detection will be done in JavaScript)
-        $this->_userprefsOfferImport = false;
-        if ($GLOBALS['PMA_Config']->get('user_preferences') == 'session'
+        $this->userprefsOfferImport = false;
+        if ($GLOBALS['PMA_Config']->get('user_preferences') === 'session'
             && ! isset($_SESSION['userprefs_autoload'])
         ) {
-            $this->_userprefsOfferImport = true;
+            $this->userprefsOfferImport = true;
         }
 
         $this->userPreferences = new UserPreferences();
@@ -153,58 +156,56 @@ class Header
 
     /**
      * Loads common scripts
-     *
-     * @return void
      */
-    private function _addDefaultScripts(): void
+    private function addDefaultScripts(): void
     {
         // Localised strings
-        $this->_scripts->addFile('vendor/jquery/jquery.min.js');
-        $this->_scripts->addFile('vendor/jquery/jquery-migrate.js');
-        $this->_scripts->addFile('whitelist.php');
-        $this->_scripts->addFile('vendor/sprintf.js');
-        $this->_scripts->addFile('ajax.js');
-        $this->_scripts->addFile('keyhandler.js');
-        $this->_scripts->addFile('vendor/bootstrap/bootstrap.bundle.min.js');
-        $this->_scripts->addFile('vendor/jquery/jquery-ui.min.js');
-        $this->_scripts->addFile('vendor/js.cookie.js');
-        $this->_scripts->addFile('vendor/jquery/jquery.mousewheel.js');
-        $this->_scripts->addFile('vendor/jquery/jquery.event.drag-2.2.js');
-        $this->_scripts->addFile('vendor/jquery/jquery.validate.js');
-        $this->_scripts->addFile('vendor/jquery/jquery-ui-timepicker-addon.js');
-        $this->_scripts->addFile('vendor/jquery/jquery.ba-hashchange-1.3.js');
-        $this->_scripts->addFile('vendor/jquery/jquery.debounce-1.0.5.js');
-        $this->_scripts->addFile('menu_resizer.js');
+        $this->scripts->addFile('vendor/jquery/jquery.min.js');
+        $this->scripts->addFile('vendor/jquery/jquery-migrate.js');
+        $this->scripts->addFile('vendor/sprintf.js');
+        $this->scripts->addFile('ajax.js');
+        $this->scripts->addFile('keyhandler.js');
+        $this->scripts->addFile('vendor/bootstrap/bootstrap.bundle.min.js');
+        $this->scripts->addFile('vendor/jquery/jquery-ui.min.js');
+        $this->scripts->addFile('vendor/js.cookie.js');
+        $this->scripts->addFile('vendor/jquery/jquery.mousewheel.js');
+        $this->scripts->addFile('vendor/jquery/jquery.event.drag-2.2.js');
+        $this->scripts->addFile('vendor/jquery/jquery.validate.js');
+        $this->scripts->addFile('vendor/jquery/jquery-ui-timepicker-addon.js');
+        $this->scripts->addFile('vendor/jquery/jquery.ba-hashchange-2.0.js');
+        $this->scripts->addFile('vendor/jquery/jquery.debounce-1.0.6.js');
+        $this->scripts->addFile('menu_resizer.js');
 
         // Cross-framing protection
         if ($GLOBALS['cfg']['AllowThirdPartyFraming'] === false) {
-            $this->_scripts->addFile('cross_framing_protection.js');
+            $this->scripts->addFile('cross_framing_protection.js');
         }
 
-        $this->_scripts->addFile('rte.js');
+        $this->scripts->addFile('rte.js');
         if ($GLOBALS['cfg']['SendErrorReports'] !== 'never') {
-            $this->_scripts->addFile('vendor/tracekit.js');
-            $this->_scripts->addFile('error_report.js');
+            $this->scripts->addFile('vendor/tracekit.js');
+            $this->scripts->addFile('error_report.js');
         }
 
         // Here would not be a good place to add CodeMirror because
         // the user preferences have not been merged at this point
 
-        $this->_scripts->addFile('messages.php', ['l' => $GLOBALS['lang']]);
-        $this->_scripts->addFile('config.js');
-        $this->_scripts->addFile('doclinks.js');
-        $this->_scripts->addFile('functions.js');
-        $this->_scripts->addFile('navigation.js');
-        $this->_scripts->addFile('indexes.js');
-        $this->_scripts->addFile('common.js');
-        $this->_scripts->addFile('page_settings.js');
+        $this->scripts->addFile('messages.php', ['l' => $GLOBALS['lang']]);
+        $this->scripts->addCode($this->getVariablesForJavaScript());
+        $this->scripts->addFile('config.js');
+        $this->scripts->addFile('doclinks.js');
+        $this->scripts->addFile('functions.js');
+        $this->scripts->addFile('navigation.js');
+        $this->scripts->addFile('indexes.js');
+        $this->scripts->addFile('common.js');
+        $this->scripts->addFile('page_settings.js');
         if ($GLOBALS['cfg']['enable_drag_drop_import'] === true) {
-            $this->_scripts->addFile('drag_drop_import.js');
+            $this->scripts->addFile('drag_drop_import.js');
         }
         if (! $GLOBALS['PMA_Config']->get('DisableShortcutKeys')) {
-            $this->_scripts->addFile('shortcuts_handler.js');
+            $this->scripts->addFile('shortcuts_handler.js');
         }
-        $this->_scripts->addCode($this->getJsParamsCode());
+        $this->scripts->addCode($this->getJsParamsCode());
     }
 
     /**
@@ -215,21 +216,21 @@ class Header
      */
     public function getJsParams(): array
     {
-        $db = strlen($GLOBALS['db']) ? $GLOBALS['db'] : '';
-        $table = strlen($GLOBALS['table']) ? $GLOBALS['table'] : '';
-        $pftext = isset($_SESSION['tmpval']['pftext'])
-            ? $_SESSION['tmpval']['pftext'] : '';
+        global $db, $table, $dbi;
+
+        $pftext = $_SESSION['tmpval']['pftext'] ?? '';
 
         $params = [
-            'common_query' => Url::getCommonRaw(),
+            // Do not add any separator, JS code will decide
+            'common_query' => Url::getCommonRaw([], ''),
             'opendb_url' => Util::getScriptNameForOption(
                 $GLOBALS['cfg']['DefaultTabDatabase'],
                 'database'
             ),
             'lang' => $GLOBALS['lang'],
             'server' => $GLOBALS['server'],
-            'table' => $table,
-            'db' => $db,
+            'table' => $table ?? '',
+            'db' => $db ?? '',
             'token' => $_SESSION[' PMA_token '],
             'text_dir' => $GLOBALS['text_dir'],
             'show_databases_navigation_as_tree' => $GLOBALS['cfg']['ShowDatabasesNavigationAsTree'],
@@ -247,15 +248,13 @@ class Header
             'confirm' => $GLOBALS['cfg']['Confirm'],
             'LoginCookieValidity' => $GLOBALS['cfg']['LoginCookieValidity'],
             'session_gc_maxlifetime' => (int) ini_get('session.gc_maxlifetime'),
-            'logged_in' => isset($GLOBALS['dbi']) ? $GLOBALS['dbi']->isUserType('logged') : false,
+            'logged_in' => isset($dbi) ? $dbi->isConnected() : false,
             'is_https' => $GLOBALS['PMA_Config']->isHttps(),
             'rootPath' => $GLOBALS['PMA_Config']->getRootPath(),
             'arg_separator' => Url::getArgSeparator(),
             'PMA_VERSION' => PMA_VERSION,
         ];
-        if (isset($GLOBALS['cfg']['Server'])
-            && isset($GLOBALS['cfg']['Server']['auth_type'])
-        ) {
+        if (isset($GLOBALS['cfg']['Server'], $GLOBALS['cfg']['Server']['auth_type'])) {
             $params['auth_type'] = $GLOBALS['cfg']['Server']['auth_type'];
             if (isset($GLOBALS['cfg']['Server']['user'])) {
                 $params['user'] = $GLOBALS['cfg']['Server']['user'];
@@ -268,8 +267,6 @@ class Header
     /**
      * Returns, as a string, a list of parameters
      * used on the client side
-     *
-     * @return string
      */
     public function getJsParamsCode(): string
     {
@@ -281,17 +278,16 @@ class Header
                 $params[$key] = $key . ':"' . Sanitize::escapeJsString($value) . '"';
             }
         }
+
         return 'CommonParams.setAll({' . implode(',', $params) . '});';
     }
 
     /**
      * Disables the rendering of the header
-     *
-     * @return void
      */
     public function disable(): void
     {
-        $this->_isEnabled = false;
+        $this->isEnabled = false;
     }
 
     /**
@@ -299,13 +295,11 @@ class Header
      * we are servicing an ajax request
      *
      * @param bool $isAjax Whether we are servicing an ajax request
-     *
-     * @return void
      */
     public function setAjax(bool $isAjax): void
     {
-        $this->_isAjax = $isAjax;
-        $this->_console->setAjax($isAjax);
+        $this->isAjax = $isAjax;
+        $this->console->setAjax($isAjax);
     }
 
     /**
@@ -315,7 +309,7 @@ class Header
      */
     public function getScripts(): Scripts
     {
-        return $this->_scripts;
+        return $this->scripts;
     }
 
     /**
@@ -325,64 +319,54 @@ class Header
      */
     public function getMenu(): Menu
     {
-        return $this->_menu;
+        return $this->menu;
     }
 
     /**
      * Setter for the ID attribute in the BODY tag
      *
      * @param string $id Value for the ID attribute
-     *
-     * @return void
      */
     public function setBodyId(string $id): void
     {
-        $this->_bodyId = htmlspecialchars($id);
+        $this->bodyId = htmlspecialchars($id);
     }
 
     /**
      * Setter for the title of the page
      *
      * @param string $title New title
-     *
-     * @return void
      */
     public function setTitle(string $title): void
     {
-        $this->_title = htmlspecialchars($title);
+        $this->title = htmlspecialchars($title);
     }
 
     /**
      * Disables the display of the top menu
-     *
-     * @return void
      */
     public function disableMenuAndConsole(): void
     {
-        $this->_menuEnabled = false;
-        $this->_console->disable();
+        $this->menuEnabled = false;
+        $this->console->disable();
     }
 
     /**
      * Disables the display of the top menu
-     *
-     * @return void
      */
     public function disableWarnings(): void
     {
-        $this->_warningsEnabled = false;
+        $this->warningsEnabled = false;
     }
 
     /**
      * Turns on 'print view' mode
-     *
-     * @return void
      */
     public function enablePrintView(): void
     {
         $this->disableMenuAndConsole();
         $this->setTitle(__('Print view') . ' - phpMyAdmin ' . PMA_VERSION);
-        $this->_isPrintView = true;
+        $this->isPrintView = true;
     }
 
     /**
@@ -392,103 +376,106 @@ class Header
      */
     public function getDisplay(): string
     {
-        if (! $this->_headerIsSent && $this->_isEnabled) {
-            if (! $this->_isAjax) {
-                $this->sendHttpHeaders();
+        global $db, $table, $PMA_Theme, $dbi;
 
-                $baseDir = defined('PMA_PATH_TO_BASEDIR') ? PMA_PATH_TO_BASEDIR : '';
-                $uniqueValue = $GLOBALS['PMA_Config']->getThemeUniqueValue();
-                $themePath = $GLOBALS['pmaThemePath'];
-                $version = self::getVersionParameter();
-
-                // The user preferences have been merged at this point
-                // so we can conditionally add CodeMirror
-                if ($GLOBALS['cfg']['CodemirrorEnable']) {
-                    $this->_scripts->addFile('vendor/codemirror/lib/codemirror.js');
-                    $this->_scripts->addFile('vendor/codemirror/mode/sql/sql.js');
-                    $this->_scripts->addFile('vendor/codemirror/addon/runmode/runmode.js');
-                    $this->_scripts->addFile('vendor/codemirror/addon/hint/show-hint.js');
-                    $this->_scripts->addFile('vendor/codemirror/addon/hint/sql-hint.js');
-                    if ($GLOBALS['cfg']['LintEnable']) {
-                        $this->_scripts->addFile('vendor/codemirror/addon/lint/lint.js');
-                        $this->_scripts->addFile(
-                            'codemirror/addon/lint/sql-lint.js'
-                        );
-                    }
-                }
-                $this->_scripts->addCode(
-                    'ConsoleEnterExecutes='
-                    . ($GLOBALS['cfg']['ConsoleEnterExecutes'] ? 'true' : 'false')
-                );
-                $this->_scripts->addFiles($this->_console->getScripts());
-                if ($this->_userprefsOfferImport) {
-                    $this->_scripts->addFile('config.js');
-                }
-
-                if ($this->_menuEnabled && $GLOBALS['server'] > 0) {
-                    $nav = new Navigation(
-                        $this->template,
-                        new Relation($GLOBALS['dbi']),
-                        $GLOBALS['dbi']
-                    );
-                    $navigation = $nav->getDisplay();
-                }
-
-                $customHeader = Config::renderHeader();
-
-                // offer to load user preferences from localStorage
-                if ($this->_userprefsOfferImport) {
-                    $loadUserPreferences = $this->userPreferences->autoloadGetHeader();
-                }
-
-                if ($this->_menuEnabled && $GLOBALS['server'] > 0) {
-                    $menu = $this->_menu->getDisplay();
-                }
-                $console = $this->_console->getDisplay();
-                $messages = $this->getMessage();
-            }
-            if (empty($_REQUEST['recent_table'])) {
-                $recentTable = $this->_addRecentTable(
-                    $GLOBALS['db'],
-                    $GLOBALS['table']
-                );
-            }
-            return $this->template->render('header', [
-                'is_ajax' => $this->_isAjax,
-                'is_enabled' => $this->_isEnabled,
-                'lang' => $GLOBALS['lang'],
-                'allow_third_party_framing' => $GLOBALS['cfg']['AllowThirdPartyFraming'],
-                'is_print_view' => $this->_isPrintView,
-                'base_dir' => $baseDir ?? '',
-                'unique_value' => $uniqueValue ?? '',
-                'theme_path' => $themePath ?? '',
-                'version' => $version ?? '',
-                'text_dir' => $GLOBALS['text_dir'],
-                'server' => $GLOBALS['server'] ?? null,
-                'title' => $this->getPageTitle(),
-                'scripts' => $this->_scripts->getDisplay(),
-                'body_id' => $this->_bodyId,
-                'navigation' => $navigation ?? '',
-                'custom_header' => $customHeader ?? '',
-                'load_user_preferences' => $loadUserPreferences ?? '',
-                'show_hint' => $GLOBALS['cfg']['ShowHint'],
-                'is_warnings_enabled' => $this->_warningsEnabled,
-                'is_menu_enabled' => $this->_menuEnabled,
-                'menu' => $menu ?? '',
-                'console' => $console ?? '',
-                'messages' => $messages ?? '',
-                'has_recent_table' => empty($_REQUEST['recent_table']),
-                'recent_table' => $recentTable ?? '',
-            ]);
+        if ($this->headerIsSent || ! $this->isEnabled) {
+            return '';
         }
-        return '';
+
+        $recentTable = '';
+        if (empty($_REQUEST['recent_table'])) {
+            $recentTable = $this->addRecentTable($db, $table);
+        }
+
+        if ($this->isAjax) {
+            return $recentTable;
+        }
+
+        $this->sendHttpHeaders();
+
+        $baseDir = defined('PMA_PATH_TO_BASEDIR') ? PMA_PATH_TO_BASEDIR : '';
+        $uniqueValue = $GLOBALS['PMA_Config']->getThemeUniqueValue();
+        $themePath = $PMA_Theme !== null ? $PMA_Theme->getPath() : '';
+        $version = self::getVersionParameter();
+
+        // The user preferences have been merged at this point
+        // so we can conditionally add CodeMirror
+        if ($GLOBALS['cfg']['CodemirrorEnable']) {
+            $this->scripts->addFile('vendor/codemirror/lib/codemirror.js');
+            $this->scripts->addFile('vendor/codemirror/mode/sql/sql.js');
+            $this->scripts->addFile('vendor/codemirror/addon/runmode/runmode.js');
+            $this->scripts->addFile('vendor/codemirror/addon/hint/show-hint.js');
+            $this->scripts->addFile('vendor/codemirror/addon/hint/sql-hint.js');
+            if ($GLOBALS['cfg']['LintEnable']) {
+                $this->scripts->addFile('vendor/codemirror/addon/lint/lint.js');
+                $this->scripts->addFile(
+                    'codemirror/addon/lint/sql-lint.js'
+                );
+            }
+        }
+
+        $this->scripts->addCode(
+            'ConsoleEnterExecutes='
+            . ($GLOBALS['cfg']['ConsoleEnterExecutes'] ? 'true' : 'false')
+        );
+        $this->scripts->addFiles($this->console->getScripts());
+
+        if ($this->userprefsOfferImport) {
+            $this->scripts->addFile('config.js');
+        }
+
+        if ($this->menuEnabled && $GLOBALS['server'] > 0) {
+            $nav = new Navigation(
+                $this->template,
+                new Relation($dbi),
+                $dbi
+            );
+            $navigation = $nav->getDisplay();
+        }
+
+        $customHeader = Config::renderHeader();
+
+        // offer to load user preferences from localStorage
+        if ($this->userprefsOfferImport) {
+            $loadUserPreferences = $this->userPreferences->autoloadGetHeader();
+        }
+
+        if ($this->menuEnabled && $GLOBALS['server'] > 0) {
+            $menu = $this->menu->getDisplay();
+        }
+
+        $console = $this->console->getDisplay();
+        $messages = $this->getMessage();
+
+        return $this->template->render('header', [
+            'lang' => $GLOBALS['lang'],
+            'allow_third_party_framing' => $GLOBALS['cfg']['AllowThirdPartyFraming'],
+            'is_print_view' => $this->isPrintView,
+            'base_dir' => $baseDir,
+            'unique_value' => $uniqueValue,
+            'theme_path' => $themePath,
+            'version' => $version,
+            'text_dir' => $GLOBALS['text_dir'],
+            'server' => $GLOBALS['server'] ?? null,
+            'title' => $this->getPageTitle(),
+            'scripts' => $this->scripts->getDisplay(),
+            'body_id' => $this->bodyId,
+            'navigation' => $navigation ?? '',
+            'custom_header' => $customHeader,
+            'load_user_preferences' => $loadUserPreferences ?? '',
+            'show_hint' => $GLOBALS['cfg']['ShowHint'],
+            'is_warnings_enabled' => $this->warningsEnabled,
+            'is_menu_enabled' => $this->menuEnabled,
+            'menu' => $menu ?? '',
+            'console' => $console,
+            'messages' => $messages,
+            'recent_table' => $recentTable,
+        ]);
     }
 
     /**
      * Returns the message to be displayed at the top of
      * the page, including the executed SQL query, if any.
-     *
-     * @return string
      */
     public function getMessage(): string
     {
@@ -504,39 +491,29 @@ class Header
             if (isset($GLOBALS['buffer_message'])) {
                 $buffer_message = $GLOBALS['buffer_message'];
             }
-            $retval .= Util::getMessage($message);
+            $retval .= Generator::getMessage($message);
             if (isset($buffer_message)) {
                 $GLOBALS['buffer_message'] = $buffer_message;
             }
         }
+
         return $retval;
     }
 
     /**
      * Sends out the HTTP headers
-     *
-     * @return void
      */
     public function sendHttpHeaders(): void
     {
         if (defined('TESTSUITE')) {
             return;
         }
-        $map_tile_urls = ' *.tile.openstreetmap.org';
 
         /**
          * Sends http headers
          */
         $GLOBALS['now'] = gmdate('D, d M Y H:i:s') . ' GMT';
-        if (! empty($GLOBALS['cfg']['CaptchaLoginPrivateKey'])
-            && ! empty($GLOBALS['cfg']['CaptchaLoginPublicKey'])
-        ) {
-            $captcha_url
-                = ' https://apis.google.com https://www.google.com/recaptcha/'
-                . ' https://www.gstatic.com/recaptcha/ https://ssl.gstatic.com/ ';
-        } else {
-            $captcha_url = '';
-        }
+
         /* Prevent against ClickJacking by disabling framing */
         if (strtolower((string) $GLOBALS['cfg']['AllowThirdPartyFraming']) === 'sameorigin') {
             header(
@@ -550,56 +527,12 @@ class Header
         header(
             'Referrer-Policy: no-referrer'
         );
-        header(
-            "Content-Security-Policy: default-src 'self' "
-            . $captcha_url
-            . $GLOBALS['cfg']['CSPAllow'] . ';'
-            . "script-src 'self' 'unsafe-inline' 'unsafe-eval' "
-            . $captcha_url
-            . $GLOBALS['cfg']['CSPAllow'] . ';'
-            . "style-src 'self' 'unsafe-inline' "
-            . $captcha_url
-            . $GLOBALS['cfg']['CSPAllow']
-            . ";"
-            . "img-src 'self' data: "
-            . $GLOBALS['cfg']['CSPAllow']
-            . $map_tile_urls
-            . $captcha_url
-            . ";"
-            . "object-src 'none';"
-        );
-        header(
-            "X-Content-Security-Policy: default-src 'self' "
-            . $captcha_url
-            . $GLOBALS['cfg']['CSPAllow'] . ';'
-            . "options inline-script eval-script;"
-            . "referrer no-referrer;"
-            . "img-src 'self' data: "
-            . $GLOBALS['cfg']['CSPAllow']
-            . $map_tile_urls
-            . $captcha_url
-            . ";"
-            . "object-src 'none';"
-        );
-        header(
-            "X-WebKit-CSP: default-src 'self' "
-            . $captcha_url
-            . $GLOBALS['cfg']['CSPAllow'] . ';'
-            . "script-src 'self' "
-            . $captcha_url
-            . $GLOBALS['cfg']['CSPAllow']
-            . " 'unsafe-inline' 'unsafe-eval';"
-            . "referrer no-referrer;"
-            . "style-src 'self' 'unsafe-inline' "
-            . $captcha_url
-            . ';'
-            . "img-src 'self' data: "
-            . $GLOBALS['cfg']['CSPAllow']
-            . $map_tile_urls
-            . $captcha_url
-            . ";"
-            . "object-src 'none';"
-        );
+
+        $cspHeaders = $this->getCspHeaders();
+        foreach ($cspHeaders as $cspHeader) {
+            header($cspHeader);
+        }
+
         // Re-enable possible disabled XSS filters
         // see https://www.owasp.org/index.php/List_of_useful_HTTP_headers
         header(
@@ -626,18 +559,16 @@ class Header
             // Define the charset to be used
             header('Content-Type: text/html; charset=utf-8');
         }
-        $this->_headerIsSent = true;
+        $this->headerIsSent = true;
     }
 
     /**
      * If the page is missing the title, this function
      * will set it to something reasonable
-     *
-     * @return string
      */
     public function getPageTitle(): string
     {
-        if (strlen($this->_title) == 0) {
+        if (strlen($this->title) == 0) {
             if ($GLOBALS['server'] > 0) {
                 if (strlen($GLOBALS['table'])) {
                     $temp_title = $GLOBALS['cfg']['TitleTable'];
@@ -648,14 +579,88 @@ class Header
                 } else {
                     $temp_title = $GLOBALS['cfg']['TitleDefault'];
                 }
-                $this->_title = htmlspecialchars(
+                $this->title = htmlspecialchars(
                     Util::expandUserString($temp_title)
                 );
             } else {
-                $this->_title = 'phpMyAdmin';
+                $this->title = 'phpMyAdmin';
             }
         }
-        return $this->_title;
+
+        return $this->title;
+    }
+
+    /**
+     * Get all the CSP allow policy headers
+     *
+     * @return string[]
+     */
+    private function getCspHeaders(): array
+    {
+        global $cfg;
+
+        $mapTileUrls = ' *.tile.openstreetmap.org';
+        $captchaUrl = '';
+        $cspAllow = $cfg['CSPAllow'];
+
+        if (! empty($cfg['CaptchaApi'])
+            && ! empty($cfg['CaptchaRequestParam'])
+            && ! empty($cfg['CaptchaResponseParam'])
+            && ! empty($cfg['CaptchaLoginPrivateKey'])
+            && ! empty($cfg['CaptchaLoginPublicKey'])
+        ) {
+            $captchaUrl = ' ' . $cfg['CaptchaCsp'] . ' ';
+        }
+
+        return [
+
+            "Content-Security-Policy: default-src 'self' "
+                . $captchaUrl
+                . $cspAllow . ';'
+                . "script-src 'self' 'unsafe-inline' 'unsafe-eval' "
+                . $captchaUrl
+                . $cspAllow . ';'
+                . "style-src 'self' 'unsafe-inline' "
+                . $captchaUrl
+                . $cspAllow
+                . ';'
+                . "img-src 'self' data: "
+                . $cspAllow
+                . $mapTileUrls
+                . $captchaUrl
+                . ';'
+                . "object-src 'none';",
+
+            "X-Content-Security-Policy: default-src 'self' "
+                . $captchaUrl
+                . $cspAllow . ';'
+                . 'options inline-script eval-script;'
+                . 'referrer no-referrer;'
+                . "img-src 'self' data: "
+                . $cspAllow
+                . $mapTileUrls
+                . $captchaUrl
+                . ';'
+                . "object-src 'none';",
+
+            "X-WebKit-CSP: default-src 'self' "
+                . $captchaUrl
+                . $cspAllow . ';'
+                . "script-src 'self' "
+                . $captchaUrl
+                . $cspAllow
+                . " 'unsafe-inline' 'unsafe-eval';"
+                . 'referrer no-referrer;'
+                . "style-src 'self' 'unsafe-inline' "
+                . $captchaUrl
+                . ';'
+                . "img-src 'self' data: "
+                . $cspAllow
+                . $mapTileUrls
+                . $captchaUrl
+                . ';'
+                . "object-src 'none';",
+        ];
     }
 
     /**
@@ -663,13 +668,11 @@ class Header
      *
      * @param string $db    Database name where the table is located.
      * @param string $table The table name
-     *
-     * @return string
      */
-    private function _addRecentTable(string $db, string $table): string
+    private function addRecentTable(string $db, string $table): string
     {
         $retval = '';
-        if ($this->_menuEnabled
+        if ($this->menuEnabled
             && strlen($table) > 0
             && $GLOBALS['cfg']['NumRecentTables'] > 0
         ) {
@@ -684,6 +687,7 @@ class Header
                 $retval = $error->getDisplay();
             }
         }
+
         return $retval;
     }
 
@@ -691,10 +695,24 @@ class Header
      * Returns the phpMyAdmin version to be appended to the url to avoid caching
      * between versions
      *
-     * @return string urlenocded pma version as a parameter
+     * @return string urlencoded pma version as a parameter
      */
     public static function getVersionParameter(): string
     {
-        return "v=" . urlencode(PMA_VERSION);
+        return 'v=' . urlencode(PMA_VERSION);
+    }
+
+    private function getVariablesForJavaScript(): string
+    {
+        global $cfg, $PMA_Theme;
+
+        $maxInputVars = ini_get('max_input_vars');
+        $maxInputVarsValue = $maxInputVars === false || $maxInputVars === '' ? 'false' : (int) $maxInputVars;
+
+        return $this->template->render('javascript/variables', [
+            'first_day_of_calendar' => $cfg['FirstDayOfCalendar'],
+            'theme_image_path' => $PMA_Theme !== null ? $PMA_Theme->getImgPath() : '',
+            'max_input_vars' => $maxInputVarsValue,
+        ]);
     }
 }
