@@ -1,24 +1,19 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Functionality for the navigation tree
- *
- * @package PhpMyAdmin-Navigation
  */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Navigation\Nodes;
 
-use PhpMyAdmin\Relation;
+use PhpMyAdmin\Html\Generator;
 use PhpMyAdmin\Url;
-use PhpMyAdmin\Util;
 
 /**
  * Represents a node that is a child of a database node
  * This may either be a concrete child such as table or a container
  * such as table container
- *
- * @package PhpMyAdmin-Navigation
  */
 abstract class NodeDatabaseChild extends Node
 {
@@ -32,9 +27,9 @@ abstract class NodeDatabaseChild extends Node
     /**
      * Returns HTML for control buttons displayed infront of a node
      *
-     * @return String HTML for control buttons
+     * @return string HTML for control buttons
      */
-    public function getHtmlForControlButtons()
+    public function getHtmlForControlButtons(): string
     {
         $ret = '';
         $cfgRelation = $this->relation->getRelationsParam();
@@ -50,10 +45,10 @@ abstract class NodeDatabaseChild extends Node
             ];
 
             $ret = '<span class="navItemControls">'
-                . '<a href="navigation.php" data-post="'
+                . '<a href="' . Url::getFromRoute('/navigation') . '" data-post="'
                 . Url::getCommon($params, '') . '"'
                 . ' class="hideNavItem ajax">'
-                . Util::getImage('hide', __('Hide'))
+                . Generator::getImage('hide', __('Hide'))
                 . '</a></span>';
         }
 
