@@ -1,20 +1,16 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Image JPEG Link Transformations plugin for phpMyAdmin
- *
- * @package    PhpMyAdmin-Transformations
- * @subpackage Link
  */
+
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Plugins\Transformations\Output;
 
 use PhpMyAdmin\Plugins\Transformations\Abs\ImageLinkTransformationsPlugin;
 
 /**
  * Handles the link transformation for image jpeg
- *
- * @package    PhpMyAdmin-Transformations
- * @subpackage Link
  */
 // @codingStandardsIgnoreLine
 class Image_JPEG_Link extends ImageLinkTransformationsPlugin
@@ -26,7 +22,7 @@ class Image_JPEG_Link extends ImageLinkTransformationsPlugin
      */
     public static function getMIMEType()
     {
-        return "Image";
+        return 'Image';
     }
 
     /**
@@ -36,6 +32,6 @@ class Image_JPEG_Link extends ImageLinkTransformationsPlugin
      */
     public static function getMIMESubtype()
     {
-        return "JPEG";
+        return 'JPEG';
     }
 }
