@@ -1,11 +1,8 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Blob SQL Transformations plugin for phpMyAdmin
- *
- * @package    PhpMyAdmin-Transformations
- * @subpackage SQL
  */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Plugins\Transformations\Output;
@@ -14,9 +11,6 @@ use PhpMyAdmin\Plugins\Transformations\Abs\SQLTransformationsPlugin;
 
 /**
  * Handles the sql transformation for blob data
- *
- * @package    PhpMyAdmin-Transformations
- * @subpackage SQL
  */
 // @codingStandardsIgnoreLine
 class Text_Octetstream_Sql extends SQLTransformationsPlugin
@@ -28,7 +22,7 @@ class Text_Octetstream_Sql extends SQLTransformationsPlugin
      */
     public static function getMIMEType()
     {
-        return "Text";
+        return 'Text';
     }
 
     /**
@@ -38,6 +32,6 @@ class Text_Octetstream_Sql extends SQLTransformationsPlugin
      */
     public static function getMIMESubtype()
     {
-        return "Octetstream";
+        return 'Octetstream';
     }
 }
