@@ -1,18 +1,13 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Tracking changes on databases, tables and views
- *
- * @package PhpMyAdmin
  */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin;
 
-use PhpMyAdmin\DatabaseInterface;
-use PhpMyAdmin\Plugins;
 use PhpMyAdmin\Plugins\Export\ExportSql;
-use PhpMyAdmin\Relation;
 use PhpMyAdmin\SqlParser\Parser;
 use PhpMyAdmin\SqlParser\Statements\AlterStatement;
 use PhpMyAdmin\SqlParser\Statements\CreateStatement;
@@ -22,34 +17,50 @@ use PhpMyAdmin\SqlParser\Statements\InsertStatement;
 use PhpMyAdmin\SqlParser\Statements\RenameStatement;
 use PhpMyAdmin\SqlParser\Statements\TruncateStatement;
 use PhpMyAdmin\SqlParser\Statements\UpdateStatement;
-use PhpMyAdmin\Util;
+use function array_values;
+use function count;
+use function explode;
+use function is_array;
+use function mb_strpos;
+use function mb_strstr;
+use function mb_substr;
+use function preg_quote;
+use function preg_replace;
+use function rtrim;
+use function serialize;
+use function str_replace;
+use function strtotime;
+use function substr;
+use function trim;
 
 /**
  * This class tracks changes on databases, tables and views.
  *
- * @package PhpMyAdmin
- *
  * @todo use stristr instead of strstr
  */
 class Tracker
 {
     /**
      * Whether tracking is ready.
+     *
+     * @var bool
      */
     protected static $enabled = false;
 
     /**
      * Cache to avoid quering tracking status multiple times.
+     *
+     * @var array
      */
-    protected static $_tracking_cache = [];
+    protected static $trackingCache = [];
 
     /**
      * Actually enables tracking. This needs to be done after all
      * underlaying code is initialized.
      *
-     * @static
-     *
      * @return void
+     *
+     * @static
      */
     public static function enable()
     {
@@ -59,12 +70,14 @@ class Tracker
     /**
      * Gets the on/off value of the Tracker module, starts initialization.
      *
-     * @static
+     * @return bool (true=on|false=off)
      *
-     * @return boolean (true=on|false=off)
+     * @static
      */
     public static function isActive()
     {
+        global $dbi;
+
         if (! self::$enabled) {
             return false;
         }
@@ -72,7 +85,7 @@ class Tracker
          * from Relation::getRelationsParam
          */
         self::$enabled = false;
-        $relation = new Relation($GLOBALS['dbi']);
+        $relation = new Relation($dbi);
         $cfgRelation = $relation->getRelationsParam();
         /* Restore original state */
         self::$enabled = true;
@@ -80,7 +93,7 @@ class Tracker
             return false;
         }
 
-        $pma_table = self::_getTrackingTable();
+        $pma_table = self::getTrackingTable();
 
         return $pma_table !== null;
     }
@@ -90,9 +103,9 @@ class Tracker
      *
      * @param string $string part of SQL statement
      *
-     * @static
-     *
      * @return string the name of table
+     *
+     * @static
      */
     protected static function getTableName($string)
     {
@@ -112,31 +125,32 @@ class Tracker
         return $tablename;
     }
 
-
     /**
-     * Gets the tracking status of a table, is it active or deactive ?
+     * Gets the tracking status of a table, is it active or disabled ?
      *
      * @param string $dbname    name of database
      * @param string $tablename name of table
      *
-     * @static
+     * @return bool true or false
      *
-     * @return boolean true or false
+     * @static
      */
     public static function isTracked($dbname, $tablename)
     {
+        global $dbi;
+
         if (! self::$enabled) {
             return false;
         }
 
-        if (isset(self::$_tracking_cache[$dbname][$tablename])) {
-            return self::$_tracking_cache[$dbname][$tablename];
+        if (isset(self::$trackingCache[$dbname][$tablename])) {
+            return self::$trackingCache[$dbname][$tablename];
         }
         /* We need to avoid attempt to track any queries
          * from Relation::getRelationsParam
          */
         self::$enabled = false;
-        $relation = new Relation($GLOBALS['dbi']);
+        $relation = new Relation($dbi);
         $cfgRelation = $relation->getRelationsParam();
         /* Restore original state */
         self::$enabled = true;
@@ -144,14 +158,14 @@ class Tracker
             return false;
         }
 
-        $sql_query = " SELECT tracking_active FROM " . self::_getTrackingTable() .
-        " WHERE db_name = '" . $GLOBALS['dbi']->escapeString($dbname) . "' " .
-        " AND table_name = '" . $GLOBALS['dbi']->escapeString($tablename) . "' " .
-        " ORDER BY version DESC LIMIT 1";
+        $sql_query = ' SELECT tracking_active FROM ' . self::getTrackingTable() .
+        " WHERE db_name = '" . $dbi->escapeString($dbname) . "' " .
+        " AND table_name = '" . $dbi->escapeString($tablename) . "' " .
+        ' ORDER BY version DESC LIMIT 1';
 
-        $result = $GLOBALS['dbi']->fetchValue($sql_query, 0, 0, DatabaseInterface::CONNECT_CONTROL) == 1;
+        $result = $dbi->fetchValue($sql_query, 0, 0, DatabaseInterface::CONNECT_CONTROL) == 1;
 
-        self::$_tracking_cache[$dbname][$tablename] = $result;
+        self::$trackingCache[$dbname][$tablename] = $result;
 
         return $result;
     }
@@ -166,7 +180,7 @@ class Tracker
         $date = Util::date('Y-m-d H:i:s');
         $user = preg_replace('/\s+/', ' ', $GLOBALS['cfg']['Server']['user']);
 
-        return "# log " . $date . " " . $user . "\n";
+        return '# log ' . $date . ' ' . $user . "\n";
     }
 
     /**
@@ -179,9 +193,9 @@ class Tracker
      * @param string $tracking_set set of tracking statements
      * @param bool   $is_view      if table is a view
      *
-     * @static
-     *
      * @return int result of version insertion
+     *
+     * @static
      */
     public static function createVersion(
         $dbname,
@@ -190,9 +204,9 @@ class Tracker
         $tracking_set = '',
         bool $is_view = false
     ) {
-        global $sql_backquotes, $export_type;
+        global $sql_backquotes, $export_type, $dbi;
 
-        $relation = new Relation($GLOBALS['dbi']);
+        $relation = new Relation($dbi);
 
         if ($tracking_set == '') {
             $tracking_set
@@ -201,11 +215,12 @@ class Tracker
 
         /**
          * get Export SQL instance
+         *
          * @var ExportSql $export_sql_plugin
          */
         $export_sql_plugin = Plugins::getPlugin(
-            "export",
-            "sql",
+            'export',
+            'sql',
             'libraries/classes/Plugins/Export/',
             [
                 'export_type' => $export_type,
@@ -219,7 +234,7 @@ class Tracker
 
         // Get data definition snapshot of table
 
-        $columns = $GLOBALS['dbi']->getColumns($dbname, $tablename, null, true);
+        $columns = $dbi->getColumns($dbname, $tablename, null, true);
         // int indices to reduce size
         $columns = array_values($columns);
         // remove Privileges to reduce size
@@ -227,7 +242,7 @@ class Tracker
             unset($columns[$i]['Privileges']);
         }
 
-        $indexes = $GLOBALS['dbi']->getTableIndexes($dbname, $tablename);
+        $indexes = $dbi->getTableIndexes($dbname, $tablename);
 
         $snapshot = [
             'COLUMNS' => $columns,
@@ -238,7 +253,7 @@ class Tracker
         // Get DROP TABLE / DROP VIEW and CREATE TABLE SQL statements
         $sql_backquotes = true;
 
-        $create_sql  = "";
+        $create_sql  = '';
 
         if ($GLOBALS['cfg']['Server']['tracking_add_drop_table'] == true
             && $is_view === false
@@ -255,32 +270,32 @@ class Tracker
         }
 
         $create_sql .= self::getLogComment() .
-            $export_sql_plugin->getTableDef($dbname, $tablename, "\n", "");
+            $export_sql_plugin->getTableDef($dbname, $tablename, "\n", '');
 
         // Save version
 
         $sql_query = "/*NOTRACK*/\n" .
-        "INSERT INTO " . self::_getTrackingTable() . " (" .
-        "db_name, " .
-        "table_name, " .
-        "version, " .
-        "date_created, " .
-        "date_updated, " .
-        "schema_snapshot, " .
-        "schema_sql, " .
-        "data_sql, " .
-        "tracking " .
-        ") " .
+        'INSERT INTO ' . self::getTrackingTable() . ' (' .
+        'db_name, ' .
+        'table_name, ' .
+        'version, ' .
+        'date_created, ' .
+        'date_updated, ' .
+        'schema_snapshot, ' .
+        'schema_sql, ' .
+        'data_sql, ' .
+        'tracking ' .
+        ') ' .
         "values (
-        '" . $GLOBALS['dbi']->escapeString($dbname) . "',
-        '" . $GLOBALS['dbi']->escapeString($tablename) . "',
-        '" . $GLOBALS['dbi']->escapeString($version) . "',
-        '" . $GLOBALS['dbi']->escapeString($date) . "',
-        '" . $GLOBALS['dbi']->escapeString($date) . "',
-        '" . $GLOBALS['dbi']->escapeString($snapshot) . "',
-        '" . $GLOBALS['dbi']->escapeString($create_sql) . "',
-        '" . $GLOBALS['dbi']->escapeString("\n") . "',
-        '" . $GLOBALS['dbi']->escapeString($tracking_set)
+        '" . $dbi->escapeString($dbname) . "',
+        '" . $dbi->escapeString($tablename) . "',
+        '" . $dbi->escapeString($version) . "',
+        '" . $dbi->escapeString($date) . "',
+        '" . $dbi->escapeString($date) . "',
+        '" . $dbi->escapeString($snapshot) . "',
+        '" . $dbi->escapeString($create_sql) . "',
+        '" . $dbi->escapeString("\n") . "',
+        '" . $dbi->escapeString($tracking_set)
         . "' )";
 
         $result = $relation->queryAsControlUser($sql_query);
@@ -293,7 +308,6 @@ class Tracker
         return $result;
     }
 
-
     /**
      * Removes all tracking data for a table or a version of a table
      *
@@ -301,24 +315,27 @@ class Tracker
      * @param string $tablename name of table
      * @param string $version   version
      *
-     * @static
-     *
      * @return int result of version insertion
+     *
+     * @static
      */
     public static function deleteTracking($dbname, $tablename, $version = '')
     {
-        $relation = new Relation($GLOBALS['dbi']);
+        global $dbi;
+
+        $relation = new Relation($dbi);
 
         $sql_query = "/*NOTRACK*/\n"
-            . "DELETE FROM " . self::_getTrackingTable()
+            . 'DELETE FROM ' . self::getTrackingTable()
             . " WHERE `db_name` = '"
-            . $GLOBALS['dbi']->escapeString($dbname) . "'"
+            . $dbi->escapeString($dbname) . "'"
             . " AND `table_name` = '"
-            . $GLOBALS['dbi']->escapeString($tablename) . "'";
+            . $dbi->escapeString($tablename) . "'";
         if ($version) {
             $sql_query .= " AND `version` = '"
-                . $GLOBALS['dbi']->escapeString($version) . "'";
+                . $dbi->escapeString($version) . "'";
         }
+
         return $relation->queryAsControlUser($sql_query);
     }
 
@@ -331,9 +348,9 @@ class Tracker
      * @param string $query        query
      * @param string $tracking_set set of tracking statements
      *
-     * @static
-     *
      * @return int result of version insertion
+     *
+     * @static
      */
     public static function createDatabaseVersion(
         $dbname,
@@ -341,7 +358,9 @@ class Tracker
         $query,
         $tracking_set = 'CREATE DATABASE,ALTER DATABASE,DROP DATABASE'
     ) {
-        $relation = new Relation($GLOBALS['dbi']);
+        global $dbi;
+
+        $relation = new Relation($dbi);
 
         $date = Util::date('Y-m-d H:i:s');
 
@@ -350,7 +369,7 @@ class Tracker
                 = $GLOBALS['cfg']['Server']['tracking_default_statements'];
         }
 
-        $create_sql  = "";
+        $create_sql  = '';
 
         if ($GLOBALS['cfg']['Server']['tracking_add_drop_database'] == true) {
             $create_sql .= self::getLogComment()
@@ -361,59 +380,59 @@ class Tracker
 
         // Save version
         $sql_query = "/*NOTRACK*/\n" .
-        "INSERT INTO " . self::_getTrackingTable() . " (" .
-        "db_name, " .
-        "table_name, " .
-        "version, " .
-        "date_created, " .
-        "date_updated, " .
-        "schema_snapshot, " .
-        "schema_sql, " .
-        "data_sql, " .
-        "tracking " .
-        ") " .
+        'INSERT INTO ' . self::getTrackingTable() . ' (' .
+        'db_name, ' .
+        'table_name, ' .
+        'version, ' .
+        'date_created, ' .
+        'date_updated, ' .
+        'schema_snapshot, ' .
+        'schema_sql, ' .
+        'data_sql, ' .
+        'tracking ' .
+        ') ' .
         "values (
-        '" . $GLOBALS['dbi']->escapeString($dbname) . "',
-        '" . $GLOBALS['dbi']->escapeString('') . "',
-        '" . $GLOBALS['dbi']->escapeString($version) . "',
-        '" . $GLOBALS['dbi']->escapeString($date) . "',
-        '" . $GLOBALS['dbi']->escapeString($date) . "',
-        '" . $GLOBALS['dbi']->escapeString('') . "',
-        '" . $GLOBALS['dbi']->escapeString($create_sql) . "',
-        '" . $GLOBALS['dbi']->escapeString("\n") . "',
-        '" . $GLOBALS['dbi']->escapeString($tracking_set)
+        '" . $dbi->escapeString($dbname) . "',
+        '" . $dbi->escapeString('') . "',
+        '" . $dbi->escapeString($version) . "',
+        '" . $dbi->escapeString($date) . "',
+        '" . $dbi->escapeString($date) . "',
+        '" . $dbi->escapeString('') . "',
+        '" . $dbi->escapeString($create_sql) . "',
+        '" . $dbi->escapeString("\n") . "',
+        '" . $dbi->escapeString($tracking_set)
         . "' )";
 
         return $relation->queryAsControlUser($sql_query);
     }
 
-
-
     /**
      * Changes tracking of a table.
      *
-     * @param string  $dbname    name of database
-     * @param string  $tablename name of table
-     * @param string  $version   version
-     * @param integer $new_state the new state of tracking
-     *
-     * @static
+     * @param string $dbname    name of database
+     * @param string $tablename name of table
+     * @param string $version   version
+     * @param int    $new_state the new state of tracking
      *
      * @return int result of SQL query
+     *
+     * @static
      */
-    private static function _changeTracking(
+    private static function changeTracking(
         $dbname,
         $tablename,
         $version,
         $new_state
     ) {
-        $relation = new Relation($GLOBALS['dbi']);
+        global $dbi;
 
-        $sql_query = " UPDATE " . self::_getTrackingTable() .
+        $relation = new Relation($dbi);
+
+        $sql_query = ' UPDATE ' . self::getTrackingTable() .
         " SET `tracking_active` = '" . $new_state . "' " .
-        " WHERE `db_name` = '" . $GLOBALS['dbi']->escapeString($dbname) . "' " .
-        " AND `table_name` = '" . $GLOBALS['dbi']->escapeString($tablename) . "' " .
-        " AND `version` = '" . $GLOBALS['dbi']->escapeString((string) $version) . "' ";
+        " WHERE `db_name` = '" . $dbi->escapeString($dbname) . "' " .
+        " AND `table_name` = '" . $dbi->escapeString($tablename) . "' " .
+        " AND `version` = '" . $dbi->escapeString((string) $version) . "' ";
 
         return $relation->queryAsControlUser($sql_query);
     }
@@ -427,9 +446,9 @@ class Tracker
      * @param string       $type      type of data(DDL || DML)
      * @param string|array $new_data  the new tracking data
      *
-     * @static
-     *
      * @return bool result of change
+     *
+     * @static
      */
     public static function changeTrackingData(
         $dbname,
@@ -438,11 +457,13 @@ class Tracker
         $type,
         $new_data
     ) {
-        $relation = new Relation($GLOBALS['dbi']);
+        global $dbi;
 
-        if ($type == 'DDL') {
+        $relation = new Relation($dbi);
+
+        if ($type === 'DDL') {
             $save_to = 'schema_sql';
-        } elseif ($type == 'DML') {
+        } elseif ($type === 'DML') {
             $save_to = 'data_sql';
         } else {
             return false;
@@ -453,17 +474,17 @@ class Tracker
         if (is_array($new_data)) {
             foreach ($new_data as $data) {
                 $new_data_processed .= '# log ' . $date . ' ' . $data['username']
-                    . $GLOBALS['dbi']->escapeString($data['statement']) . "\n";
+                    . $dbi->escapeString($data['statement']) . "\n";
             }
         } else {
             $new_data_processed = $new_data;
         }
 
-        $sql_query = " UPDATE " . self::_getTrackingTable() .
-        " SET `" . $save_to . "` = '" . $new_data_processed . "' " .
-        " WHERE `db_name` = '" . $GLOBALS['dbi']->escapeString($dbname) . "' " .
-        " AND `table_name` = '" . $GLOBALS['dbi']->escapeString($tablename) . "' " .
-        " AND `version` = '" . $GLOBALS['dbi']->escapeString($version) . "' ";
+        $sql_query = ' UPDATE ' . self::getTrackingTable() .
+        ' SET `' . $save_to . "` = '" . $new_data_processed . "' " .
+        " WHERE `db_name` = '" . $dbi->escapeString($dbname) . "' " .
+        " AND `table_name` = '" . $dbi->escapeString($tablename) . "' " .
+        " AND `version` = '" . $dbi->escapeString($version) . "' ";
 
         $result = $relation->queryAsControlUser($sql_query);
 
@@ -477,16 +498,15 @@ class Tracker
      * @param string $tablename name of table
      * @param string $version   version
      *
-     * @static
-     *
      * @return int result of SQL query
+     *
+     * @static
      */
     public static function activateTracking($dbname, $tablename, $version)
     {
-        return self::_changeTracking($dbname, $tablename, $version, 1);
+        return self::changeTracking($dbname, $tablename, $version, 1);
     }
 
-
     /**
      * Deactivates tracking of a table.
      *
@@ -494,16 +514,15 @@ class Tracker
      * @param string $tablename name of table
      * @param string $version   version
      *
-     * @static
-     *
      * @return int result of SQL query
+     *
+     * @static
      */
     public static function deactivateTracking($dbname, $tablename, $version)
     {
-        return self::_changeTracking($dbname, $tablename, $version, 0);
+        return self::changeTracking($dbname, $tablename, $version, 0);
     }
 
-
     /**
      * Gets the newest version of a tracking job
      * (in other words: gets the HEAD version).
@@ -512,28 +531,36 @@ class Tracker
      * @param string $tablename name of table
      * @param string $statement tracked statement
      *
-     * @static
-     *
      * @return int (-1 if no version exists | >  0 if a version exists)
+     *
+     * @static
      */
     public static function getVersion($dbname, $tablename, $statement = null)
     {
-        $relation = new Relation($GLOBALS['dbi']);
+        /** @var DatabaseInterface $dbi */
+        global $dbi;
 
-        $sql_query = " SELECT MAX(version) FROM " . self::_getTrackingTable() .
-        " WHERE `db_name` = '" . $GLOBALS['dbi']->escapeString($dbname) . "' " .
-        " AND `table_name` = '" . $GLOBALS['dbi']->escapeString($tablename) . "' ";
+        $relation = new Relation($dbi);
 
-        if ($statement != "") {
+        $sql_query = ' SELECT MAX(version) FROM ' . self::getTrackingTable() .
+        " WHERE `db_name` = '" . $dbi->escapeString($dbname) . "' " .
+        " AND `table_name` = '" . $dbi->escapeString($tablename) . "' ";
+
+        if ($statement != '') {
             $sql_query .= " AND FIND_IN_SET('"
-                . $statement . "',tracking) > 0" ;
+                . $statement . "',tracking) > 0";
         }
-        $row = $GLOBALS['dbi']->fetchArray($relation->queryAsControlUser($sql_query));
-        return isset($row[0])
-            ? $row[0]
-            : -1;
-    }
 
+        $result = $relation->queryAsControlUser($sql_query, false);
+
+        if ($result === false) {
+            return -1;
+        }
+
+        $row = $dbi->fetchArray($result);
+
+        return $row[0] ?? -1;
+    }
 
     /**
      * Gets the record of a tracking job.
@@ -542,25 +569,27 @@ class Tracker
      * @param string $tablename name of table
      * @param string $version   version number
      *
-     * @static
-     *
      * @return mixed record DDM log, DDL log, structure snapshot, tracked
      *         statements.
+     *
+     * @static
      */
     public static function getTrackedData($dbname, $tablename, $version)
     {
-        $relation = new Relation($GLOBALS['dbi']);
+        global $dbi;
 
-        $sql_query = " SELECT * FROM " . self::_getTrackingTable() .
-            " WHERE `db_name` = '" . $GLOBALS['dbi']->escapeString($dbname) . "' ";
+        $relation = new Relation($dbi);
+
+        $sql_query = ' SELECT * FROM ' . self::getTrackingTable() .
+            " WHERE `db_name` = '" . $dbi->escapeString($dbname) . "' ";
         if (! empty($tablename)) {
             $sql_query .= " AND `table_name` = '"
-                . $GLOBALS['dbi']->escapeString($tablename) . "' ";
+                . $dbi->escapeString($tablename) . "' ";
         }
-        $sql_query .= " AND `version` = '" . $GLOBALS['dbi']->escapeString($version)
+        $sql_query .= " AND `version` = '" . $dbi->escapeString($version)
             . "' ORDER BY `version` DESC LIMIT 1";
 
-        $mixed = $GLOBALS['dbi']->fetchAssoc($relation->queryAsControlUser($sql_query));
+        $mixed = $dbi->fetchAssoc($relation->queryAsControlUser($sql_query));
 
         // PHP 7.4 fix for accessing array offset on null
         if (! is_array($mixed)) {
@@ -584,25 +613,27 @@ class Tracker
         // Iterate tracked data definition statements
         // For each log entry we want to get date, username and statement
         foreach ($log_schema_entries as $log_entry) {
-            if (trim($log_entry) != '') {
-                $date      = mb_substr($log_entry, 0, 19);
-                $username  = mb_substr(
-                    $log_entry,
-                    20,
-                    mb_strpos($log_entry, "\n") - 20
-                );
-                if ($first_iteration) {
-                    $ddl_date_from = $date;
-                    $first_iteration = false;
-                }
-                $statement = rtrim(mb_strstr($log_entry, "\n"));
-
-                $ddlog[] = [
-                    'date' => $date,
-                    'username' => $username,
-                    'statement' => $statement,
-                ];
+            if (trim($log_entry) == '') {
+                continue;
             }
+
+            $date      = mb_substr($log_entry, 0, 19);
+            $username  = mb_substr(
+                $log_entry,
+                20,
+                mb_strpos($log_entry, "\n") - 20
+            );
+            if ($first_iteration) {
+                $ddl_date_from = $date;
+                $first_iteration = false;
+            }
+            $statement = rtrim((string) mb_strstr($log_entry, "\n"));
+
+            $ddlog[] = [
+                'date' => $date,
+                'username' => $username,
+                'statement' => $statement,
+            ];
         }
 
         $date_from = $ddl_date_from;
@@ -616,25 +647,27 @@ class Tracker
         // Iterate tracked data manipulation statements
         // For each log entry we want to get date, username and statement
         foreach ($log_data_entries as $log_entry) {
-            if (trim($log_entry) != '') {
-                $date      = mb_substr($log_entry, 0, 19);
-                $username  = mb_substr(
-                    $log_entry,
-                    20,
-                    mb_strpos($log_entry, "\n") - 20
-                );
-                if ($first_iteration) {
-                    $dml_date_from = $date;
-                    $first_iteration = false;
-                }
-                $statement = rtrim(mb_strstr($log_entry, "\n"));
-
-                $dmlog[] = [
-                    'date' => $date,
-                    'username' => $username,
-                    'statement' => $statement,
-                ];
+            if (trim($log_entry) == '') {
+                continue;
             }
+
+            $date      = mb_substr($log_entry, 0, 19);
+            $username  = mb_substr(
+                $log_entry,
+                20,
+                mb_strpos($log_entry, "\n") - 20
+            );
+            if ($first_iteration) {
+                $dml_date_from = $date;
+                $first_iteration = false;
+            }
+            $statement = rtrim((string) mb_strstr($log_entry, "\n"));
+
+            $dmlog[] = [
+                'date' => $date,
+                'username' => $username,
+                'statement' => $statement,
+            ];
         }
 
         $dml_date_to = $date;
@@ -659,7 +692,6 @@ class Tracker
         return $data;
     }
 
-
     /**
      * Parses a query. Gets
      *  - statement identifier (UPDATE, ALTER TABLE, ...)
@@ -668,14 +700,13 @@ class Tracker
      *
      * @param string $query query
      *
+     * @return array containing identifier, type and tablename.
+     *
      * @static
      * @todo: using PMA SQL Parser when possible
      * @todo: support multi-table/view drops
-     *
-     * @return mixed Array containing identifier, type and tablename.
-     *
      */
-    public static function parseQuery($query)
+    public static function parseQuery($query): array
     {
         // Usage of PMA_SQP does not work here
         //
@@ -688,7 +719,7 @@ class Tracker
         $tokens = $parser->list->tokens;
 
         // Parse USE statement, need it for SQL dump imports
-        if ($tokens[0]->value == 'USE') {
+        if ($tokens[0]->value === 'USE') {
             $GLOBALS['db'] = $tokens[2]->value;
         }
 
@@ -709,55 +740,55 @@ class Tracker
                     return $result;
                 }
 
-                if ($options[6] == 'VIEW' || $options[6] == 'TABLE') {
+                if ($options[6] === 'VIEW' || $options[6] === 'TABLE') {
                     $result['identifier'] = 'CREATE ' . $options[6];
-                    $result['tablename']  = $statement->name->table ;
-                } elseif ($options[6] == 'DATABASE') {
-                    $result['identifier'] = 'CREATE DATABASE' ;
-                    $result['tablename']  = '' ;
+                    $result['tablename']  = $statement->name->table;
+                } elseif ($options[6] === 'DATABASE') {
+                    $result['identifier'] = 'CREATE DATABASE';
+                    $result['tablename']  = '';
 
-                    // In case of CREATE DATABASE, table field of the CreateStatement is actually name of the database
-                    $GLOBALS['db']        = $statement->name->table;
-                } elseif ($options[6] == 'INDEX'
-                          || $options[6] == 'UNIQUE INDEX'
-                          || $options[6] == 'FULLTEXT INDEX'
-                          || $options[6] == 'SPATIAL INDEX'
+                    // In case of CREATE DATABASE, database field of the CreateStatement is the name of the database
+                    $GLOBALS['db']        = $statement->name->database;
+                } elseif ($options[6] === 'INDEX'
+                          || $options[6] === 'UNIQUE INDEX'
+                          || $options[6] === 'FULLTEXT INDEX'
+                          || $options[6] === 'SPATIAL INDEX'
                 ) {
                     $result['identifier'] = 'CREATE INDEX';
 
                     // In case of CREATE INDEX, we have to get the table name from body of the statement
-                    $result['tablename']  = $statement->body[3]->value == '.' ? $statement->body[4]->value
-                                                                              : $statement->body[2]->value ;
+                    $result['tablename']  = $statement->body[3]->value === '.' ? $statement->body[4]->value
+                                                                              : $statement->body[2]->value;
                 }
             } elseif ($statement instanceof AlterStatement) { // Parse ALTER statement
                 if (empty($options) || ! isset($options[3])) {
                     return $result;
                 }
 
-                if ($options[3] == 'VIEW' || $options[3] == 'TABLE') {
-                    $result['identifier']   = 'ALTER ' . $options[3] ;
-                    $result['tablename']    = $statement->table->table ;
-                } elseif ($options[3] == 'DATABASE') {
-                    $result['identifier']   = 'ALTER DATABASE' ;
-                    $result['tablename']    = '' ;
+                if ($options[3] === 'VIEW' || $options[3] === 'TABLE') {
+                    $result['identifier']   = 'ALTER ' . $options[3];
+                    $result['tablename']    = $statement->table->table;
+                } elseif ($options[3] === 'DATABASE') {
+                    $result['identifier']   = 'ALTER DATABASE';
+                    $result['tablename']    = '';
 
-                    $GLOBALS['db']          = $statement->table->table ;
+                    $GLOBALS['db']          = $statement->table->table;
                 }
             } elseif ($statement instanceof DropStatement) { // Parse DROP statement
                 if (empty($options) || ! isset($options[1])) {
                     return $result;
                 }
 
-                if ($options[1] == 'VIEW' || $options[1] == 'TABLE') {
-                    $result['identifier'] = 'DROP ' . $options[1] ;
+                if ($options[1] === 'VIEW' || $options[1] === 'TABLE') {
+                    $result['identifier'] = 'DROP ' . $options[1];
                     $result['tablename']  = $statement->fields[0]->table;
-                } elseif ($options[1] == 'DATABASE') {
-                    $result['identifier'] = 'DROP DATABASE' ;
+                } elseif ($options[1] === 'DATABASE') {
+                    $result['identifier'] = 'DROP DATABASE';
                     $result['tablename']  = '';
 
                     $GLOBALS['db']        = $statement->fields[0]->table;
-                } elseif ($options[1] == 'INDEX') {
-                    $result['identifier']   = 'DROP INDEX' ;
+                } elseif ($options[1] === 'INDEX') {
+                    $result['identifier']   = 'DROP INDEX';
                     $result['tablename']    = $statement->table->table;
                 }
             } elseif ($statement instanceof RenameStatement) { // Parse RENAME statement
@@ -767,7 +798,7 @@ class Tracker
             }
 
             if (isset($result['identifier'])) {
-                return $result ;
+                return $result;
             }
 
             /*
@@ -795,7 +826,7 @@ class Tracker
 
             // Parse TRUNCATE statement
             if ($statement instanceof TruncateStatement) {
-                $result['identifier']   = 'TRUNCATE' ;
+                $result['identifier']   = 'TRUNCATE';
                 $result['tablename']    = $statement->table->table;
             }
         }
@@ -803,33 +834,34 @@ class Tracker
         return $result;
     }
 
-
     /**
      * Analyzes a given SQL statement and saves tracking data.
      *
      * @param string $query a SQL query
      *
-     * @static
-     *
      * @return void
+     *
+     * @static
      */
     public static function handleQuery($query)
     {
-        $relation = new Relation($GLOBALS['dbi']);
+        global $dbi;
+
+        $relation = new Relation($dbi);
 
         // If query is marked as untouchable, leave
-        if (mb_strstr($query, "/*NOTRACK*/")) {
+        if (mb_strstr($query, '/*NOTRACK*/')) {
             return;
         }
 
-        if (! (substr($query, -1) == ';')) {
+        if (! (substr($query, -1) === ';')) {
             $query .= ";\n";
         }
         // Get some information about query
         $result = self::parseQuery($query);
 
         // Get database name
-        $dbname = trim(isset($GLOBALS['db']) ? $GLOBALS['db'] : '', '`');
+        $dbname = trim($GLOBALS['db'] ?? '', '`');
         // $dbname can be empty, for example when coming from Synchronize
         // and this is a query for the remote server
         if (empty($dbname)) {
@@ -837,94 +869,98 @@ class Tracker
         }
 
         // If we found a valid statement
-        if (isset($result['identifier'])) {
-            if (! self::isTracked($dbname, $result['tablename'])) {
-                return;
-            }
+        if (! isset($result['identifier'])) {
+            return;
+        }
 
-            $version = self::getVersion(
-                $dbname,
-                $result['tablename'],
-                $result['identifier']
-            );
+        $version = self::getVersion(
+            $dbname,
+            $result['tablename'],
+            $result['identifier']
+        );
 
-            // If version not exists and auto-creation is enabled
-            if ($GLOBALS['cfg']['Server']['tracking_version_auto_create'] == true
-                && $version == -1
-            ) {
-                // Create the version
+        // If version not exists and auto-creation is enabled
+        if ($GLOBALS['cfg']['Server']['tracking_version_auto_create'] == true
+            && $version == -1
+        ) {
+            // Create the version
 
-                switch ($result['identifier']) {
-                    case 'CREATE TABLE':
-                        self::createVersion($dbname, $result['tablename'], '1');
-                        break;
-                    case 'CREATE VIEW':
-                        self::createVersion(
-                            $dbname,
-                            $result['tablename'],
-                            '1',
-                            '',
-                            true
-                        );
-                        break;
-                    case 'CREATE DATABASE':
-                        self::createDatabaseVersion($dbname, '1', $query);
-                        break;
-                } // end switch
-            }
-
-            // If version exists
-            if ($version != -1) {
-                if ($result['type'] == 'DDL') {
-                    $save_to = 'schema_sql';
-                } elseif ($result['type'] == 'DML') {
-                    $save_to = 'data_sql';
-                } else {
-                    $save_to = '';
-                }
-                $date  = Util::date('Y-m-d H:i:s');
-
-                // Cut off `dbname`. from query
-                $query = preg_replace(
-                    '/`' . preg_quote($dbname, '/') . '`\s?\./',
-                    '',
-                    $query
-                );
-
-                // Add log information
-                $query = self::getLogComment() . $query ;
-
-                // Mark it as untouchable
-                $sql_query = " /*NOTRACK*/\n"
-                    . " UPDATE " . self::_getTrackingTable()
-                    . " SET " . Util::backquote($save_to)
-                    . " = CONCAT( " . Util::backquote($save_to) . ",'\n"
-                    . $GLOBALS['dbi']->escapeString($query) . "') ,"
-                    . " `date_updated` = '" . $date . "' ";
-
-                // If table was renamed we have to change
-                // the tablename attribute in pma_tracking too
-                if ($result['identifier'] == 'RENAME TABLE') {
-                    $sql_query .= ', `table_name` = \''
-                        . $GLOBALS['dbi']->escapeString($result['tablename_after_rename'])
-                        . '\' ';
-                }
-
-                // Save the tracking information only for
-                //     1. the database
-                //     2. the table / view
-                //     3. the statements
-                // we want to track
-                $sql_query .=
-                " WHERE FIND_IN_SET('" . $result['identifier'] . "',tracking) > 0" .
-                " AND `db_name` = '" . $GLOBALS['dbi']->escapeString($dbname) . "' " .
-                " AND `table_name` = '"
-                . $GLOBALS['dbi']->escapeString($result['tablename']) . "' " .
-                " AND `version` = '" . $GLOBALS['dbi']->escapeString($version) . "' ";
-
-                $relation->queryAsControlUser($sql_query);
+            switch ($result['identifier']) {
+                case 'CREATE TABLE':
+                    self::createVersion($dbname, $result['tablename'], '1');
+                    break;
+                case 'CREATE VIEW':
+                    self::createVersion(
+                        $dbname,
+                        $result['tablename'],
+                        '1',
+                        '',
+                        true
+                    );
+                    break;
+                case 'CREATE DATABASE':
+                    self::createDatabaseVersion($dbname, '1', $query);
+                    break;
             }
         }
+
+        // If version exists
+        if ($version == -1) {
+            return;
+        }
+
+        if (! self::isTracked($dbname, $result['tablename'])) {
+            return;
+        }
+
+        if ($result['type'] === 'DDL') {
+            $save_to = 'schema_sql';
+        } elseif ($result['type'] === 'DML') {
+            $save_to = 'data_sql';
+        } else {
+            $save_to = '';
+        }
+        $date  = Util::date('Y-m-d H:i:s');
+
+        // Cut off `dbname`. from query
+        $query = preg_replace(
+            '/`' . preg_quote($dbname, '/') . '`\s?\./',
+            '',
+            $query
+        );
+
+        // Add log information
+        $query = self::getLogComment() . $query;
+
+        // Mark it as untouchable
+        $sql_query = " /*NOTRACK*/\n"
+            . ' UPDATE ' . self::getTrackingTable()
+            . ' SET ' . Util::backquote($save_to)
+            . ' = CONCAT( ' . Util::backquote($save_to) . ",'\n"
+            . $dbi->escapeString($query) . "') ,"
+            . " `date_updated` = '" . $date . "' ";
+
+        // If table was renamed we have to change
+        // the tablename attribute in pma_tracking too
+        if ($result['identifier'] === 'RENAME TABLE') {
+            $sql_query .= ', `table_name` = \''
+                . $dbi->escapeString($result['tablename_after_rename'])
+                . '\' ';
+        }
+
+        // Save the tracking information only for
+        //     1. the database
+        //     2. the table / view
+        //     3. the statements
+        // we want to track
+        $sql_query .=
+        " WHERE FIND_IN_SET('" . $result['identifier'] . "',tracking) > 0" .
+        " AND `db_name` = '" . $dbi->escapeString($dbname ?? '') . "' " .
+        " AND `table_name` = '"
+        . $dbi->escapeString($result['tablename']) . "' " .
+        " AND `version` = '" . $dbi->escapeString($version ?? '') . "' ";
+
+        $relation->queryAsControlUser($sql_query);
     }
 
     /**
@@ -932,10 +968,13 @@ class Tracker
      *
      * @return string tracking table
      */
-    private static function _getTrackingTable()
+    private static function getTrackingTable()
     {
-        $relation = new Relation($GLOBALS['dbi']);
+        global $dbi;
+
+        $relation = new Relation($dbi);
         $cfgRelation = $relation->getRelationsParam();
+
         return Util::backquote($cfgRelation['db'])
             . '.' . Util::backquote($cfgRelation['tracking']);
     }
